<?php
/*
* 2011 Judith Buetas Solanellas
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future.
*
*  @author Judith Buetas Solanellas <jbuetass@uoc.edu>
*  @copyright  2011 Judith Buetas Solanellas
*  @date 08/12/2011
*  @version  Release: $Revision: 1.0 $
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*/

//////////////////////////////////////////////////////////////////////////////////////////
//INSTALACIÓN
//////////////////////////////////////////////////////////////////////////////////////////

class abandonedShoppingCarts extends Module
{
	const INSTALL_SQL_FILE = 'install.sql';
	const UNINSTALL_SQL_FILE = 'uninstall.sql';

	private $_html = '';
	private $_postErrors = array();
	private $_baseUrl;

	const NUM_ITEMS_PAGINATOR = 10;
	
// Constructor de la clase abandoned shopping carts	
	public function __construct()
	{
		$this->name = 'abandonedshoppingcarts';
		$this->tab = 'back_office_features';
		$this->version = '1.0';
		$this->author = 'Judith Buetas';
		$this->need_instance = 0;

		parent::__construct();
		$this->page = basename(__FILE__, '.php'); //ubicamos la ruta hacia nuestro archivo
		$this->displayName = $this->l('Abandoned Shopping Carts');
		$this->description = $this->l('Allow users to Recovering Abandoned Shopping Carts.');
	}

// Instalamos el módulo desde el apartado de módulos del Back Office
// Crea tablas de la BD, crea variables de configuration, copia archivos, traslada módulos (registerHook), etc. y comprueba su correcta instalación
	public function install()
	{
		if (!file_exists(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return false;
		elseif (!$sql = file_get_contents(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return false;
			
		$sql = str_replace(array('PREFIX_', 'ENGINE_TYPE'), array(_DB_PREFIX_, _MYSQL_ENGINE_), $sql);		
		$sql = preg_split("/;\s*[\r\n]+/", trim($sql));

		foreach ($sql AS $query)
			if (!Db::getInstance()->Execute(trim($query)))
				return false;				

		if (parent::install() == false 
			OR !Configuration::updateValue('ABANDONED_CART_NDAYS_SEND_MAIL', 5)
        )
			return false;
		return true;
    }

// Desinstalamos el módulo desde el apartado de módulos del Back Office
// Elimina tablas de la Base de datos y variables de configuracion	
	function uninstall()
	{
		//uninstall tables
		if (!file_exists(dirname(__FILE__).'/'.self::UNINSTALL_SQL_FILE)) {
			echo $this->l('Cannot find [uninstall.sql]! (aborted)');
			return (false); 
        }else if (!$sql = file_get_contents(dirname(__FILE__).'/'.self::UNINSTALL_SQL_FILE)) {
			echo $this->l('Cannot open [uninstall.sql]! (aborted)');
			return (false); 
        }
        
		$sql = str_replace('PREFIX_', _DB_PREFIX_, $sql);
		$sql = preg_split("/;\s*[\r\n]+/",$sql);
		
		foreach ($sql as $query)
			if (!Db::getInstance()->Execute(trim($query))) {
                echo $this->l('Cannot remove abandoned_shopping_carts_emails table from database! (aborted)');
			return false;
		}
		
		if (!parent::uninstall() 
			OR !Configuration::deleteByName('ABANDONED_CART_NDAYS_SEND_MAIL') 
		)
			return false;
		return true;
	}
	
//////////////////////////////////////////////////////////////////////////////////////////
//BACK OFFICE
//////////////////////////////////////////////////////////////////////////////////////////

// Permite acceder a la configuración del módulo (incluso vacia)
	public function getContent()
	{
		$this->_setBaseUrl();
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_postProcess();
		
		return $this->_html.$this->_displayForm();
	}

// Generamos la URL base del módulo Abandoned Shopping Carts en la administración	
	private function _setBaseUrl()
	{
		$this->_baseUrl = 'index.php?';
		foreach ($_GET AS $k => $value)
				$this->_baseUrl .= $k.'='.$value.'&';
		$this->_baseUrl = rtrim($this->_baseUrl, '&');
	}

// Actualización de los datos de los diferentes apartados de configuración del módulo Abandoned Shopping Carts
	protected function _postProcess()
	{	
		if (Tools::isSubmit('submitAbandonedShoppingCartsConfiguration'))
		{
			Configuration::updateValue('ABANDONED_CART_NDAYS_SEND_MAIL', (int)Tools::getValue('abandoned_cart_ndays_send_mail'));
			
			$this->_html .= $this->displayConf($this->l('Settings updated'));
		}
	}

// Mostrar mensaje de Datos actualizados
	public function displayConf($text)
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$text.'
		</div>';
	}

// Muestra los diferentes apartados de configuración del módulo Abandoned Shopping Carts
	private function _displayForm()
	{
		$this->_html = '';
		$this->_displayInformation();
		$this->_displayFormAbandonedShoppingCartsConfiguration();
		$this->_displayTableAbandonedShoppingCarts();
		return $this->_html;
	}
	
// Muestra información importante sobre el módulo
	private function _displayInformation()
	{
		//esta url depende del dominio indicado en preferencias, en principio está bien así
		$this->_html .= '<fieldset>
    			<legend>
                    <span>'.$this->l('Information').'</span>
                </legend>
                <p>
                    '.$this->l('For sending mails "Recovering Shopping Carts" is automatic, you must set a cron job using the following URL: ')._PS_BASE_URL_.'/modules/'.$this->name.'/cron.php'.'
               	</p>
                <p style="color:#FE1212;font-weight:bold">                    
                    '.$this->l('Note: If you uninstall the module, all email advices will be deleting. But if you disable the module, the email advices will be continue save.').'
                </p>
            </fieldset>
            <br/>';          
	}

// Muestra formulario de configuración de Abandoned Shopping Carts
	private function _displayFormAbandonedShoppingCartsConfiguration()
	{
		$this->_html .= '<fieldset class="width3">';
		$this->_html .= '<legend><img src="../img/admin/cog.gif" alt="" title="" />'.$this->l('Configuration').'</legend>';
		$this->_html .= '<form action="'.$this->_baseUrl.'" method="post" name="abandoned_shopping_carts_configuration">';  
		//indicaremos el número de días en que se enviará el correo de recuerdo
		$this->_html .= '<label>'.$this->l('Number of days to send mail:').'</label>
                            <div class="margin-form">
            					<input type="text" size="2" maxlength="2" id="abandoned_cart_ndays_send_mail" name="abandoned_cart_ndays_send_mail" value="'.Configuration::get('ABANDONED_CART_NDAYS_SEND_MAIL').'" />
                                <p style="font-size:12px">'.$this->l('Set the number of days in which the customer after the purchase is abandoned must receive the message asking him to finish it.').'</p>
            				</div>
            			<div class="clear" style="height: 20px;"></div>';  
		$this->_html .= '<div class="margin-form clear">
						<input type="submit" name="submitAbandonedShoppingCartsConfiguration" value="'.$this->l('Save').'" class="button" />
						</div>';
		$this->_html .= '</form>';
		$this->_html .= '</fieldset><br />';
	}

// Permite paginar el listado de compras abandonadas
	private function _displayPaginatorAbandonedShoppingCarts()
	{
		$submitFilterName = 'AbandonedCarts';
		$action_url = 'index.php?tab=AdminModules&configure='.$this->name;
		
		require_once(dirname(__FILE__).'/abandonedShoppingCartsSql.php');
    	
		$abandonedShoppingCartsSql = new abandonedShoppingCartsSql();
    	
		//Consultamos el listado de compras abandonadas	
		$aAbandonedShoppingCarts = $abandonedShoppingCartsSql->checkAbandonedPurchasesWithMails();
		
		// Determine total rows number
		$totalRows = count($aAbandonedShoppingCarts);
		
		//Determine number items paginator
		$num_items_paginator = self::NUM_ITEMS_PAGINATOR;

		// Determine total page number
		$totalPages = ceil($totalRows / $num_items_paginator);
		
		// Determine current page number 
		$page = (int)(Tools::getValue('submitFilter'.$submitFilterName));

		if (!$page) $page = 1;
		
		//Items per page
		$items_ini = $num_items_paginator*$page-$num_items_paginator;
		$items_end = $num_items_paginator*$page;
		
		//Determine last number items paginator
		if($num_items_paginator*$page > (int)$totalRows)
		{
			$items_end = (int)($totalRows);
		}
		
		$text =  '<a name="'.$submitFilterName.'">&nbsp;</a>
		<form method="post" action="'.$action_url.'&token='.Tools::getAdminTokenLite('AdminModules'). '#'.$submitFilterName.'" class="form">
		<input type="hidden" id="submitFilter'.$submitFilterName.'" name="submitFilter'.$submitFilterName.'" value="0">
		<div style="padding: 2px;">';

		if ($page > 1)
			$text .=  '<input type="image" src="../img/admin/list-prev2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value=1"/>&nbsp; 
					<input type="image" src="../img/admin/list-prev.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page - 1).'"/> ';
		$text .=  $this->l('Page').' <b>'.$page.'</b> / '.$totalPages.'&nbsp;';
		
		if ($page < $totalPages)
			$text .=  '<input type="image" src="../img/admin/list-next.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page + 1).'"/>&nbsp;
					<input type="image" src="../img/admin/list-next2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.$totalPages.'"/>';

		$text .=  ' | '.$this->l('Display').' '.$items_ini.' '.$this->l('to').' '.$items_end.' / '.(int)($totalRows).' '.$this->l('result(s)');
		$text .=  '</div>
		</form>';

		return $text;
	}

	// Muestra listado de compras abandonadas e indica si se les ha enviado el mail de recuerdo
	private function _displayTableAbandonedShoppingCarts()
	{
		require_once(dirname(__FILE__).'/abandonedShoppingCartsSql.php');
		
		$abandonedShoppingCartsSql = new abandonedShoppingCartsSql();
		
		//paginator
		$start_paginator = 0;
			
		if(isset($_REQUEST['submitFilterAbandonedCarts']))
		{
			$start_paginator = ($_REQUEST['submitFilterAbandonedCarts']-1)*self::NUM_ITEMS_PAGINATOR ;
		}
		
		//Consultamos el listado de compras abandonadas	
		$aAbandonedShoppingCarts = $abandonedShoppingCartsSql->checkAbandonedPurchasesWithMails($start_paginator, self::NUM_ITEMS_PAGINATOR);
		
		$this->_html .= '<fieldset class="width3">';
		$this->_html .= '<legend>'.$this->l('Abandoned Shopping Carts List').'</legend>';
		
		if (sizeof($aAbandonedShoppingCarts))
		{	
			$this->_html .= $this->_displayPaginatorAbandonedShoppingCarts();
		
			$this->_html .= '
				<table id="table_abandoned_carts" class="table" border="0" cellspacing="0" cellpadding="0">
				<thead>
				<tr>
					<th style="width:150px;">'.ucfirst($this->l('date')).'</th>
					<th style="width:150px;">'.ucfirst($this->l('customer name')).'</th>
					<th style="width:150px;">'.ucfirst($this->l('order')).'</th>
					<th style="width:550px;">'.ucfirst($this->l('payment')).'</th>
					<th style="width:550px;">'.ucfirst($this->l('order state')).'</th>
					<th style="width:30px;">'.ucfirst($this->l('send')).'</th>
				</tr>
				</thead>
				<tbody>';
			
			foreach ($aAbandonedShoppingCarts AS $abandonedShoppingCart)
			{					
				$send = (empty($abandonedShoppingCart['send']) ? 0 : 1);
				
				$aDate = date_parse($abandonedShoppingCart['date_add']);
				$date = $aDate['day'].'/'. $aDate['month'].'/'. $aDate['year'];
				
				$this->_html .= '
				<tr>
					<td>'.htmlspecialchars($date, ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars(ucfirst($abandonedShoppingCart['customer_name']), ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars(ucfirst(str_pad((int)$abandonedShoppingCart['id_order'], 6, "0", STR_PAD_LEFT)), ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars(ucfirst($abandonedShoppingCart['payment']), ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars(ucfirst($abandonedShoppingCart['name']), ENT_COMPAT, 'UTF-8').'</td>
				 	<td style="text-align:center">'.htmlspecialchars($send, ENT_COMPAT, 'UTF-8').'</td>
				</tr>';
			}
			
			$this->_html .= '
				</tbody>
				</table>';
		}
		else
			$this->_html .= $this->l('No abandoned Shopping Carts at this time.');

		$this->_html .= '</fieldset><br />';
	}
	
//////////////////////////////////////////////////////////////////////////////////////////
//AUTOMATIC PROCESS
//////////////////////////////////////////////////////////////////////////////////////////

// Enviamos emails de recuerdo de recuperación de compras abandonadas
    public function sendRememberRecoveringCartsEmails()
    {
    	require_once(dirname(__FILE__).'/abandonedShoppingCartsSql.php');
    	$abandonedShoppingCartsSql = new abandonedShoppingCartsSql();
            		
        $date = $this->substract_days_to_date(date("d-m-Y"), Configuration::get('ABANDONED_CART_NDAYS_SEND_MAIL') );
		$abandonedShoppingCartsSql->date = $date;
		
		$aAbandonedPurchases = $abandonedShoppingCartsSql->checkAbandonedPurchases();

        foreach ($aAbandonedPurchases AS $abandonedPurchase)
        {        
            if (!empty($abandonedPurchase))
            {
                $customer = new Customer($abandonedPurchase['id_customer']);
				$abandoned_shopping_cart_url = 'http://'.Configuration::get('PS_SHOP_DOMAIN').__PS_BASE_URI__.'historial-de-pedidos';
				
				if($abandonedPurchase['id_order_state'] == 8)
					$email_name = 'abandoned_shopping_carts_tpv_remember_email';
				else
					$email_name = 'abandoned_shopping_carts_remember_email';
					
				//si no ha llegado a ser pedido y solo esta en la cesta y quiere q tb se contemplen
				//no se como lo haré pero no servirá este método, quiza se tenga q usar otro email
                $data = array('{firstname}' => ucfirst($customer->firstname),
                          	'{lastname}' => ucfirst($customer->lastname),
                          	'{id_order}' => str_pad((int)$abandonedPurchase['id_order'], 6, "0", STR_PAD_LEFT),
                          	'{shopping_cart_url}' => $abandoned_shopping_cart_url);

                $emailResult = Mail::Send((int)($abandonedPurchase['id_lang']), $email_name, $this->l('Recover your shopping cart'), $data, $customer->email, $customer->firstname.' '.$customer->lastname, NULL, NULL, NULL, NULL, dirname(__FILE__).'/mails/');    
                print $emailResult."<br>";
                if($emailResult)
                {
            		$abandonedShoppingCartsSql->id = (int)$abandonedPurchase['id_cart'];
            		$abandonedShoppingCartsSql->send = 1;
            		$abandonedShoppingCartsSql->addAbandonedShoppingCartsEmails();
            	}
            }                         
        }
     
        return true;        
    }    
    
// Restar x días a una fecha
    function substract_days_to_date($date,$nday)
    {
        if (preg_match("/[0-9]{1,2}\/[0-9]{1,2}\/([0-9][0-9]){1,2}/",$date))
        
        list($day,$month,$year) = explode("/", $date);
        
        if (preg_match("/[0-9]{1,2}-[0-9]{1,2}-([0-9][0-9]){1,2}/",$date))
        
        list($day,$month,$year) = explode("-", $date);
        $newdate = mktime(0,0,0, $month,$day,$year) - $nday * 24 * 60 * 60;
        $newdate = date("Y-m-d",$newdate);
        
        return ($newdate);
    } 

	
//////////////////////////////////////////////////////////////////////////////////////////
//FRONT OFFICE
//////////////////////////////////////////////////////////////////////////////////////////
//no se refleja en el front office
}