<?php
/*
* 2007-2011 PrestaShop 
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2011 PrestaShop SA
*  @version  Release: $Revision: 6594 $
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_CAN_LOAD_FILES_'))
	exit;

class ProductComments extends Module
{
	const INSTALL_SQL_FILE = 'install.sql';

	private $_html = '';
	private $_postErrors = array();
	
	private $_productCommentsCriterionTypes = array();
	private $_baseUrl;
	
	/*cambiado 
	Judith Buetas
	27/11/2011
	Variables para paginador
	*/
	const NUM_ITEMS_PAGINATOR = 10;
	
	public function __construct()
	{
		$this->name = 'productcomments';
		$this->tab = 'front_office_features';
		$this->version = '2.1';
		$this->author = 'PrestaShop';
		$this->need_instance = 0;

		parent::__construct();
		$this->page = basename(__FILE__, '.php'); //ubicamos la ruta hacia nuestro archivo
		$this->displayName = $this->l('Product Comments');
		$this->description = $this->l('Allow users to post comment about a product.');
	}

	public function install()
	{
		if (!file_exists(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return false;
		elseif (!$sql = file_get_contents(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return false;
			
		$sql = str_replace(array('PREFIX_', 'ENGINE_TYPE'), array(_DB_PREFIX_, _MYSQL_ENGINE_), $sql);		
		$sql = preg_split("/;\s*[\r\n]+/", trim($sql));

		foreach ($sql AS $query)
			if (!Db::getInstance()->Execute(trim($query)))
				return false;				

		/*cambiado 
		Judith Buetas
		23/11/2011
		Añadimos variables de configuración que se añadirán si instalamos el módulo
		*/
		if (parent::install() == false 
			OR $this->registerHook('productTab') == false
			OR $this->registerHook('extraProductComparison') == false 
			OR $this->registerHook('productTabContent') == false
			OR !Configuration::updateValue('PRODUCT_COMMENTS_MINIMAL_TIME', 30)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_ALLOW_GUESTS', 0)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_MODERATE', 1)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_NOTIFY_BY_EMAIL', 1)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_NUM_DISPLAY', 10)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_ACTIVE', 1)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_APP_ID', '')
			OR !Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_SECRET', '')
			OR !Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_ACTIVE', 1)
			OR !Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_KEY', '')
			OR !Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_SECRET', '')
			OR !Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_AT', '')
			OR !Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_AT_SECR', '')
        	OR !$this->addAverageCommentProductHook()        
        	OR $this->registerHook('averageCommentProduct') == false
        	OR $this->registerHook('extraRight') == false
        )
			return false;
		return true;
    }

	function uninstall()
	{
		/*cambiado 
		Judith Buetas
		23/11/2011
		Añadimos variables de configuración que se eliminarán si desinstalamos el módulo
		*/
		if (!parent::uninstall() 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_MODERATE') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_ALLOW_GUESTS') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_MINIMAL_TIME') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_NOTIFY_BY_EMAIL') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_MAIL_NOTICE') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_NUM_DISPLAY')
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_FACEBOOK_ACTIVE') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_FACEBOOK_APP_ID') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_FACEBOOK_SECRET')
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_TWITTER_ACTIVE') 
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_TWITTER_KEY')
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_TWITTER_SECRET')
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_TWITTER_AT')
			OR !Configuration::deleteByName('PRODUCT_COMMENTS_TWITTER_AT_SECR')
			OR !$this->removeAverageCommentProductHook()
		)
			return false;
		return true;
	}
	
//////////////////////////////////////////////////////////////////////////////////////////
//BACK OFFICE
//////////////////////////////////////////////////////////////////////////////////////////

	// Permite acceder a la configuración del módulo (incluso vacia)
	public function getContent()
	{
		include_once(dirname(__FILE__).'/ProductCommentCriterion.php');
		
		$this->_setBaseUrl();		
		$this->_productCommentsCriterionTypes = ProductCommentCriterion::getTypes();
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_postProcess();
		$this->_checkModerateComment();
		$this->_checkCriterion();
		$this->_updateApplicationCriterion();

		return $this->_html.$this->_displayForm();
	}
	
	// Generamos la URL base del módulo Product Comments en la administración
	private function _setBaseUrl()
	{
		$this->_baseUrl = 'index.php?';
		foreach ($_GET AS $k => $value)
			if (!in_array($k, array('deleteCriterion', 'editCriterion')))
				$this->_baseUrl .= $k.'='.$value.'&';
		$this->_baseUrl = rtrim($this->_baseUrl, '&');
	}	
	
	// Actualización de los datos de los diferentes apartados de configuración del módulo de Product Comments
	protected function _postProcess()
	{		
		if (Tools::isSubmit('submitModerate'))
		{
			/*cambiado 
			Judith Buetas
			23/11/2011
			Añadimos variables de configuración que se modificarán al cambiar la configuración del módulo
			*/
			Configuration::updateValue('PRODUCT_COMMENTS_MODERATE', (int)Tools::getValue('moderate'));
			Configuration::updateValue('PRODUCT_COMMENTS_ALLOW_GUESTS', (int)Tools::getValue('allow_guest'));
			Configuration::updateValue('PRODUCT_COMMENTS_MINIMAL_TIME', (int)Tools::getValue('product_comments_minimal_time'));			
			Configuration::updateValue('PRODUCT_COMMENTS_NOTIFY_BY_EMAIL', Tools::getValue('product_comments_notify_by_email'));
			Configuration::updateValue('PRODUCT_COMMENTS_MAIL_NOTICE', Tools::getValue('product_comments_mail_notice'));
			Configuration::updateValue('PRODUCT_COMMENTS_NUM_DISPLAY', (int)Tools::getValue('product_comments_num_display'));
			Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_ACTIVE', Tools::getValue('product_comments_facebook_active'));
			Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_APP_ID', Tools::getValue('product_comments_facebook_app_id'));
			Configuration::updateValue('PRODUCT_COMMENTS_FACEBOOK_SECRET', Tools::getValue('product_comments_facebook_secret'));
			Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_ACTIVE', Tools::getValue('product_comments_twitter_active'));
			Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_KEY', Tools::getValue('product_comments_twitter_key'));
			Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_SECRET', Tools::getValue('product_comments_twitter_secret'));
			Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_AT', Tools::getValue('product_comments_twitter_at'));
			Configuration::updateValue('PRODUCT_COMMENTS_TWITTER_AT_SECR', Tools::getValue('product_comments_twitter_at_secr'));

			
			$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.$this->l('Settings updated').'</div>';
		}
		
		if ($id_criterion =  (int)Tools::getValue('deleteCriterion'))
		{
			$productCommentCriterion = new ProductCommentCriterion((int)$id_criterion);
			if ($productCommentCriterion->id)
				if ($productCommentCriterion->delete())
					$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.$this->l('Criterion deleted').'</div>';
		}
	}

	//check del formulario de moderar comentario
	private function _checkModerateComment()
	{
		$action = Tools::getValue('action');
		if (empty($action) === false && !(int)(Configuration::get('PRODUCT_COMMENTS_MODERATE')))
		{
			$product_comments = Tools::getValue('id_product_comment');
			if (sizeof($product_comments))
			{
				require_once(dirname(__FILE__).'/ProductComment.php');
				switch ($action)
				{
					case 'accept':
						foreach ($product_comments AS $id_product_comment)
						{
							if (!$id_product_comment)
								continue;
							$comment = new ProductComment((int)$id_product_comment);
							$comment->validate();
						}
						break;
					case 'edit':
						//cargamos el dialogo en _displayFormFeedbackModerate
						break;
					case 'save':
							if (!$id_product_comment)
								continue;
							$comment = new ProductComment((int)$id_product_comment);
							$comment->update();
						break;
					case 'delete':
					
						foreach ($product_comments AS $id_product_comment)
						{
							if (!$id_product_comment)
								continue;
							$comment = new ProductComment((int)$id_product_comment);
							$comment->delete();
							
							ProductComment::deleteGrades((int)$id_product_comment);
						}
						break;
					default:
						;
				}
			}
		}
	}
	
	//mostrar apartados administración
	private function _displayForm()
	{
		$this->_html = '';
		$this->_displayFormHeaders();
		$this->_displayFormModerate();
		$this->_displayFormConfigurationCriterion();
		$this->_displayFormApplicationCriterion();
		return $this->_html;
	}

	//añadir al código las cabeceras jss y css
	private function _displayFormHeaders()
	{
		$this->_html .= '<script type="text/javascript" src="'.$this->_path.'js/moderate.js"></script>
						<script type="text/javascript" src="'.__PS_BASE_URI__.'js/jquery/jquery-ui-1.8.10.custom.min.js"></script>
						<link rel="stylesheet" href="'.$this->_path.'css/jquery-ui-1.8.10.custom.css" type="text/css" media="all" />
						<link rel="stylesheet" href="'.$this->_path.'css/productcomments.css" type="text/css" media="all" />
						<script type="text/javascript" src="'.$this->_path.'js/productcomments_BO.js"></script>
						<script type="text/javascript">
							var productcommnts_dir = "'.$this->_path.'";
						</script>';
	}
	
	private function _displayFormModerate()
	{	
		/*cambiado 
		Judith Buetas
		23/11/2011
		Añadimos campos a la configuración para enviar mails de aviso si se envía un nuevo comentario de producto
		PRODUCT_COMMENTS_NOTIFY_BY_EMAIL
		PRODUCT_COMMENTS_MAIL_NOTICE
		
		Añadimos campos a la configuración para configurar aplicación de Facebook
		PRODUCT_COMMENTS_FACEBOOK_ACTIVE
		PRODUCT_COMMENTS_FACEBOOK_APP_ID
		PRODUCT_COMMENTS_FACEBOOK_SECRET
		
		Añadimos campos a la configuración para configurar aplicación de Twitter
		PRODUCT_COMMENTS_TWITTER_ACTIVE
		PRODUCT_COMMENTS_TWITTER_KEY
		PRODUCT_COMMENTS_TWITTER_SECRET
		PRODUCT_COMMENTS_TWITTER_AT
		PRODUCT_COMMENTS_TWITTER_AT_SECR
		*/
		
		$this->_html .= $this->_displayFormFeedbackConfiguration();
		
		if (!Configuration::get('PRODUCT_COMMENTS_MODERATE'))
		{
			$this->_html .= $this->_displayFormFeedbackModerate();
		}
	}
	
	private function _displayFormFeedbackConfiguration()
	{	
		session_start();
		
		$_SESSION['fbAppId']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID');
		$_SESSION['fbsecret']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET');
		$_SESSION['consumer_key']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY');
		$_SESSION['consumer_secret']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET');
		$_SESSION['consumer_at']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_AT');
		$_SESSION['consumer_ats']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_AT_SECR');
		
		$this->_html .= '<fieldset class="width4">
				<legend><img src="../img/admin/cog.gif" alt="" title="" />'.$this->l('Configuration').'</legend>
				<form action="'.$this->_baseUrl.'" method="post" name="comment_configuration">
					<label style="padding-top: 0;">'.$this->l('All comments must be validated by an employee').'</label>
					<div class="margin-form">
						<input type="radio" name="moderate" id="moderate_on" value="1" '.(Configuration::get('PRODUCT_COMMENTS_MODERATE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="moderate_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="moderate" id="moderate_off" value="0" '.(!Configuration::get('PRODUCT_COMMENTS_MODERATE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="moderate_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Allow guest comments').'</label>
					<div class="margin-form">
						<input type="radio" name="allow_guest" id="allow_guest_on" value="1" '.(Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS') ? 'checked="checked" ' : '').'/>
						<label class="t" for="allow_guest_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="allow_guest" id="allow_guest_off" value="0" '.(!Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS') ? 'checked="checked" ' : '').'/>
						<label class="t" for="allow_guest_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Minimum time between 2 comments from the same user').'</label>
					<div class="margin-form">
						<input name="product_comments_minimal_time" type="text" class="text" value="'.Configuration::get('PRODUCT_COMMENTS_MINIMAL_TIME').'" style="width: 40px; text-align: right;" /> '.$this->l('seconds').'
					</div>
					<!-- cambiado Judith-->
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('notify by email when someone send a new product comment').'</label>
					<div class="margin-form">
						<input type="radio" name="product_comments_notify_by_email" id="product_comments_notify_by_email_on" value="1" '.(Configuration::get('PRODUCT_COMMENTS_NOTIFY_BY_EMAIL') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_notify_by_email_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="product_comments_notify_by_email" id="product_comments_notify_by_email_off" value="0" '.(!Configuration::get('PRODUCT_COMMENTS_NOTIFY_BY_EMAIL') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_notify_by_email_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('mail addresses to notify new product comments').'</label>
					<div class="margin-form">
						<input name="product_comments_mail_notice" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_MAIL_NOTICE').'"/>
						<p style="font-size:12px">'.$this->l('enter email addresses separated by commas').'</p>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Number of product comments to display').'</label>
					<div class="margin-form">
						<input name="product_comments_num_display" type="text" class="text" size="5" value="'.Configuration::get('PRODUCT_COMMENTS_NUM_DISPLAY').'"/>
					</div>					
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Allow to comment products on Facebook by customers').'</label>
					<div class="margin-form">
						<input type="radio" name="product_comments_facebook_active" id="product_comments_facebook_active_on" value="1" '.(Configuration::get('PRODUCT_COMMENTS_FACEBOOK_ACTIVE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_facebook_active_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="product_comments_facebook_active" id="product_comments_facebook_active_off" value="0" '.(!Configuration::get('PRODUCT_COMMENTS_FACEBOOK_ACTIVE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_facebook_active_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>					
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Facebook App Id').'</label>
					<div class="margin-form">
						<input name="product_comments_facebook_app_id" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID').'"/>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Facebook secret').'</label>
					<div class="margin-form">
						<input name="product_comments_facebook_secret" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET').'"/>
					</div>					
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Allow to comment products on Twitter by customers').'</label>
					<div class="margin-form">
						<input type="radio" name="product_comments_twitter_active" id="product_comments_twitter_active_on" value="1" '.(Configuration::get('PRODUCT_COMMENTS_TWITTER_ACTIVE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_twitter_active_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="product_comments_twitter_active" id="product_comments_twitter_active_off" value="0" '.(!Configuration::get('PRODUCT_COMMENTS_TWITTER_ACTIVE') ? 'checked="checked" ' : '').'/>
						<label class="t" for="product_comments_twitter_active_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>					
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Twitter key').'</label>
					<div class="margin-form">
						<input name="product_comments_twitter_key" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY').'"/>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Twitter secret').'</label>
					<div class="margin-form">
						<input name="product_comments_twitter_secret" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET').'"/>
					</div>					
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Twitter access token').'</label>
					<div class="margin-form">
						<input name="product_comments_twitter_at" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_TWITTER_AT').'"/>
					</div>
					<div class="clear" style="height: 20px;"></div>
					<label style="padding-top: 0;">'.$this->l('Twitter access token secret').'</label>
					<div class="margin-form">
						<input name="product_comments_twitter_at_secr" type="text" class="text" size="40" value="'.Configuration::get('PRODUCT_COMMENTS_TWITTER_AT_SECR').'"/>
					</div>					
					<!-- fin cambiado Judith-->
					<div class="clear"></div>
					<div class="margin-form clear">
						<input type="submit" name="submitModerate" value="'.$this->l('Save').'" class="button" />
					</div>
				</form>
			</fieldset>
			<br />';			
	}
	
	private function _displayFormFeedbackModerate()
	{		
		require_once(dirname(__FILE__).'/ProductComment.php');
		/*cambiado 
		Judith Buetas
		25/11/2011
		Mostramos el listado de todos los comentarios junto a un link para eliminarlo o modificarlo
		*/
		$normal = false;
		if($normal)
			$comments = ProductComment::getByValidate();
		else
		{
			$start_paginator = 0;
			if(isset($_REQUEST['submitFilterProductComments']))
			{
				$start_paginator = ($_REQUEST['submitFilterProductComments']-1)*self::NUM_ITEMS_PAGINATOR;
			}
					
			$comments = ProductComment::getAllComments($start_paginator, self::NUM_ITEMS_PAGINATOR);
		}
		
		$this->_html .= '<fieldset class="width4">
		<legend><img src="'.$this->_path.'img/comments_delete.png" alt="" title="" />'.$this->l('Moderate Comments').'</legend>';

		if (sizeof($comments))
		{		
			//añadimos el dialog que mostraremos al apretar el botón editar del listado
			if(isset($_REQUEST['action']) && ($_REQUEST['action'] == 'edit'))
			{
				$this->_html .= $this->_displayFormEditProductTabContent();
			}
		
			//Mostramos el listado de todos los comentarios junto a un link para eliminarlo o modificarlo
			if(!$normal)
				$this->_html .= $this->_displayPaginatorProductComments();

			$this->_html .= '<a name="product_comments_moderate">&nbsp;</a>
			<form id="comment_form" action="'.$this->_baseUrl.'#product_comments_moderate" method="post" name="comment_form">
		  		<input type="hidden" name="id_product_comment[]" id="id_product_comment" />
				<input type="hidden" name="action" id="action" />
				<br />
				<table id="table_comments_moderate" class="table" border="0" cellspacing="0" cellpadding="0">
				<thead>
				<tr>
					<th><input class="noborder" type="checkbox" name="id_product_comment[]" onclick="checkDelBoxes(this.form, \'id_product_comment[]\', this.checked)" /></th>
					<th style="width:150px;">'.$this->l('Add Date').'</th>
					<th style="width:150px;">'.$this->l('Author').'</th>
					<th style="width:450px;">'.$this->l('Comment').'</th>
					<th style="width:150px;">'.$this->l('Product name').'</th>
					<th style="width:120px;">'.$this->l('Actions').'</th>
				</tr>
				</thead>
				<tbody>';

			foreach ($comments AS $comment)
			{	
				$link = new Link();
				$rewrite_infos = Product::getUrlRewriteInformations((int)$comment['id_product']);
				$cover = Product::getCover($comment['id_product']);
						
				foreach ($rewrite_infos AS $infos)
				{
					$default_rewrite[$infos['id_lang']] = $link->getProductLink((int)$comment['id_product'], $infos['link_rewrite'], $infos['category_rewrite'], $infos['ean13'], (int)$infos['id_lang']);
					$url_img_product = $link->getImageLink($infos['link_rewrite'], $comment['id_product']."-".$cover['id_image']);
				}
				
				$url_product = $default_rewrite[intval(Configuration::get('PS_LANG_DEFAULT'))];
				
				$aCommentToSocialNetwork = ProductComment::selectCommentToSocialNetwork($comment['id_product_comment']);
				$commentedByFacebook = '';
				$commentedByTwitter = '';
				
				foreach($aCommentToSocialNetwork as $commentToSocialNetwork)
				{
					if($commentToSocialNetwork['social_network'] == 'facebook')
						$commentedByFacebook = '<img src="'.$this->_path.'img/facebook.gif" alt="'.$this->l('Commented to Facebook').'" title="'.$this->l('Commented to Facebook').'" />';
						
					if($commentToSocialNetwork['social_network'] == 'twitter')
						$commentedByTwitter = '<img src="'.$this->_path.'img/twitter.png" alt="'.$this->l('Commented to Twitter').'" title="'.$this->l('Commented to Twitter').'" />';
				}
				
				$aDate = date_parse($comment['date_add']);
				$date = $aDate['day'].'/'. $aDate['month'].'/'. $aDate['year'];
				$this->_html .= '
				<tr>
					<td><input class="noborder" type="checkbox" value="'.$comment['id_product_comment'].'" name="id_product_comment[]" /></td>
					<td>'.$date.'</td>
					<td>'.htmlspecialchars(ucfirst($comment['customer_name']), ENT_COMPAT, 'UTF-8').'.</td>
					<td>'.$commentedByFacebook.$commentedByTwitter.htmlspecialchars(ucfirst($comment['content']), ENT_COMPAT, 'UTF-8').'</td>
					<td><a href="'.$url_product.'" target="_blank">'.htmlspecialchars($comment['name'], ENT_COMPAT, 'UTF-8').'</a></td>
					<td>';
					
						//activar o editar un comentario
						if($normal) 
							$this->_html .= '<a href="javascript:;" onclick="acceptComment(\''.(int)($comment['id_product_comment']).'\');"><img src="'.$this->_path.'img/accept.png" alt="'.$this->l('Accept').'" title="'.$this->l('Accept').'" /></a>';
						else 	
							$this->_html .= '<a href="javascript:;" onclick="editComment(\''.(int)($comment['id_product_comment']).'\');">
								<img src="../img/admin/edit.gif" alt="'.$this->l('edit').'" title="'.$this->l('edit').'" />
							</a>';

						//eliminar un comentario
						 $this->_html .= '<a href="javascript:;" onclick="if(confirm(\''.$this->l('are you sure you want to delete this comment?').'\')) deleteComment(\''.(int)($comment['id_product_comment']).'\');">
						 	<img src="'.$this->_path.'img/trash.gif" alt="'.$this->l('Delete').'" title="'.$this->l('Delete').'" />
						 </a>';
						 
						//añadir un comentario a facebook
						$this->_html .= '<img class="cls_add_comment_to_facebook" src="'.$this->_path.'img/facebook.gif" alt="'.$this->l('Add comment to Facebook').'" title="'.$this->l('Add comment to Facebook').'" />';
						 
						//añadir un comentario a twitter
						$this->_html .= '<img class="cls_add_comment_to_twitter" src="'.$this->_path.'img/twitter.png" alt="'.$this->l('Add comment to Twitter').'" title="'.$this->l('Add comment to Twitter').'" />';
						 
						$this->_html .= '</td>
						 </tr>';
					}
						$this->_html .= '
						<tr>
							<td colspan="4" style="font-weight:bold;text-align:right">'.$this->l('Selection:').'</td>
							<td>';
							if($normal) 
								$this->_html .= '<a href="javascript:;" onclick="acceptComment(0);"><img src="'.$this->_path.'img/accept.png" alt="'.$this->l('Accept').'" title="'.$this->l('Accept').'" /></a>';

							$this->_html .= '<a href="javascript:;" onclick="if(confirm(\''.$this->l('are you sure you want to delete this comment?').'\')) deleteComment(0);"><img src="'.$this->_path.'img/trash.gif" alt="'.$this->l('Delete').'" title="'.$this->l('Delete').'" /></a></td>
						</tr>
				</tbody>
				</table>
			</form>';
		}
		else
			$this->_html .= $this->l('No comments to validate at this time.');
			
		$this->_html .= '</fieldset><br />';
	}
	
	/*cambiado
	Judith Buetas
	27/11/2011
	Creamos una función que permita paginar los comentarios del producto desde el BO			
	*/

	private function _displayPaginatorProductComments()
	{
		global $cookie;
		
		$submitFilterName = 'ProductComments';
		$action_url = 'index.php?tab=AdminModules&configure='.$this->name;
				
		// Determine total comments number
		$totalRows = ProductComment::getProductCommentsNumber();
		
		//Determine number items paginator
		$num_items_paginator = self::NUM_ITEMS_PAGINATOR;

		// Determine total page number
		$totalPages = ceil($totalRows / $num_items_paginator);

		// Determine current page number 
		$page = (int)(Tools::getValue('submitFilter'.$submitFilterName));

		if (!$page) $page = 1;
		
		//Items per page
		$items_ini = $num_items_paginator*$page-$num_items_paginator;
		$items_end = $num_items_paginator*$page;
		
		//Determine last number items paginator
		if($num_items_paginator*$page > (int)$totalRows)
		{
			$items_end = (int)($totalRows);
		}
		
		$text =  '<a name="'.$submitFilterName.'">&nbsp;</a>
		<form method="post" action="'.$action_url.'&token='.Tools::getAdminTokenLite('AdminModules'). '#'.$submitFilterName.'" class="form">
		<input type="hidden" id="submitFilter'.$submitFilterName.'" name="submitFilter'.$submitFilterName.'" value="0">
		<div style="padding: 2px;">';

		if ($page > 1)
			$text .=  '<input type="image" src="../img/admin/list-prev2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value=1"/>&nbsp; 
					<input type="image" src="../img/admin/list-prev.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page - 1).'"/> ';
		$text .=  $this->l('Page').' <b>'.$page.'</b> / '.$totalPages.'&nbsp;';
		
		if ($page < $totalPages)
			$text .=  '<input type="image" src="../img/admin/list-next.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page + 1).'"/>&nbsp;
					<input type="image" src="../img/admin/list-next2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.$totalPages.'"/>';

		$text .=  ' | '.$this->l('Display').' '.$items_ini.' '.$this->l('to').' '.$items_end.' / '.(int)($totalRows).' '.$this->l('result(s)');
		$text .=  '</div>
		</form>';
		return $text;
	}

    /*cambiado
	Judith Buetas
	25/11/2011
	Creamos una función que permita modificar un comentario del producto desde el BO			
	*/
	private function _displayFormEditProductTabContent()
	{
		global $cookie;

		$id_product_comment = $_REQUEST['id_product_comment'][0];
		$comment = ProductComment::getByProductCommentId($id_product_comment);

		$criterions = ProductCommentCriterion::getByProduct((int)Tools::getValue('id_product'), (int)$cookie->id_lang);		
		$allow_guests = (int)Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS');
		$grades = ProductComment::getGradesByProductComment($id_product_comment);

		$this->_html .= '<div id="edit_product_comment_dialog" title="'.$this->l('Modify this product comment').'">
						<script type="text/javascript" src="'.__PS_BASE_URI__.'js/jquery.rating.pack.js"></script>
						<script type="text/javascript">
							$(function(){ $(\'input[@type=radio].star\').rating(); });
							$(function(){							
								$(\'.auto-submit-star\').rating({
									callback: function(value, link){
									}
								});
							});	
							//close  comment form
							function closeCommentForm(){
								$(\'#sendComment\').slideUp(\'fast\');
								$(\'input#addCommentButton\').fadeIn(\'slow\');
							}
						</script>
						
						<script type="text/javascript">
							var allow_guests = '.$allow_guests.';
							var productcomments_dir = "'._MODULE_DIR_.$this->name.'/";
							var msg_empty_rate = "'.$this->l('empty rate',"productcomments").'";
	        				var msg_empty_customer_name = "'.$this->l('empty customer name',"productcomments").'";
	        				var msg_empty_title = "'.$this->l('empty title',"productcomments").'";
	        				var msg_empty_comment = "'.$this->l('empty comment',"productcomments").'";
						</script>
						
						<form action="'.$this->_baseUrl.'" method="post"  name="modify_comment_form">
						<input type="hidden" id="id_product_comment_edit" value="'.$comment[0]['id_product_comment'].'" />
						<p>'.$this->l('Modify this product comment').': <b>'.$comment[0]['name'].'</b></p>';

		$count_criterions = count($criterions);
	
		if($count_criterions > 0)
		{
			$comment_criterion_iterator = 0;
			foreach($criterions as $criterion)
			{			
				$this->_html .= '<div id="id_stars_dialog">
				<label>'. $criterion['name'].'</label>
				<input type="hidden" id="'.$comment_criterion_iterator.'_grade" value="'.$grades[$comment_criterion_iterator]['grade'].'" />
				<input class="star" type="radio" name="'.$comment_criterion_iterator.'_grade" id="'.$comment_criterion_iterator.'_grade" value="1" '.(($grades[$comment_criterion_iterator]['grade']>=1)  ? " checked=\"checked\" " : "").' />
				<input class="star" type="radio" name="'.$comment_criterion_iterator.'_grade" value="2" '.(($grades[$comment_criterion_iterator]['grade']>=2)  ? " checked=\"checked\" " : "").' />
				<input class="star" type="radio" name="'.$comment_criterion_iterator.'_grade" value="3" '.(($grades[$comment_criterion_iterator]['grade']>=3)  ? " checked=\"checked\" " : "").' />
				<input class="star" type="radio" name="'.$comment_criterion_iterator.'_grade" value="4" '.(($grades[$comment_criterion_iterator]['grade']>=4)  ? " checked=\"checked\" " : "").' />
				<input class="star" type="radio" name="'.$comment_criterion_iterator.'_grade" value="5" '.(($grades[$comment_criterion_iterator]['grade']>=5)  ? " checked=\"checked\" " : "").' />
				<script type="text/javascript">
					var count_criterions 	= '.$count_criterions.';
					var id_product_comment_criterion'.$comment_criterion_iterator.' = "'.$grades[$comment_criterion_iterator]['id_product_comment_criterion'].'";
				</script>
			</div><br>';
				$comment_criterion_iterator++;
			}
		}
		
		if(($allow_guests == true) && empty($comment[0]['id_customer']))
		{
			$this->_html .= '<div id="id_customer_name_dialog">
								<label>'.$this->l('Name').'</label>
								<input type="text" name="customer_name" id="customer_name" value="'.$comment[0]['customer_name'].'"/>
							</div><br>';		
		}

		$this->_html .= '<div id="id_title_dialog">
							<label>'.$this->l('Title').'</label>
							<input type="text" name="title" id="comment_title" value="'.$comment[0]['title'].'" />
						</div>';
		$this->_html .= '<div id="id_comment_dialog">
							<label>'.$this->l('Comment').'</label>
							<textarea cols="46" rows="5" name="comment_content" id="comment_content">'.$comment[0]['content'].'</textarea>
						</div>';
		$this->_html .= '<div id="id_button_comment_dialog">
						<input type="button" name="btnSaveProductCommentsDialog" id="btnSaveProductCommentsDialog" value="'.$this->l('Save').'" class="button" style="display: inline" />                    
						</div>';		
		$this->_html .= '</form></div><br />';
	}

// Judith Buetas Solanellas	
// 30/11/2011
// Guardamos el comentario de producto

    public function _saveProductComment($id_product_comment,$aGradeCriterium,$aGradeValue,$customer_name,$title,$comment)
    {
        global $cookie;

		require_once(dirname(__FILE__).'/ProductComment.php');
		require_once(dirname(__FILE__).'/ProductCommentCriterion.php');
	
		$originalComment = ProductComment::getByProductCommentId($id_product_comment);

		//recoger datos del comentario
		$newComment = new ProductComment();
	
		$newComment->id				= (int)$originalComment[0]['id_product_comment'];
		$newComment->id_customer 		= (int)$originalComment[0]['id_customer'];
		$newComment->id_guest 			= (int)$originalComment[0]['id_guest'];
		$newComment->id_product 		= (int)$originalComment[0]['id_product'];
		if($customer_name != NULL)
		{
     		$newComment->customer_name 		= $customer_name;
     		}
		else
		{
     		$newComment->customer_name 		= "";
     		}
		$newComment->title 			= $title;
		$newComment->content 			= $comment;
		$newComment->grade 			= 0;
		$newComment->validate 			= !Configuration::get('PRODUCT_COMMENTS_MODERATE');
		$newComment->date_add 			= $originalComment[0]['date_add'];
		print "<pre>";
		print_r($newComment);
		print "</pre>";
		//modificar comentario en la tabla productcomments
		$resultUpdate = $newComment->update();

		if($resultUpdate == true)
		{
			$count_criterions = count($aGradeCriterium);
			for($i=0, $grade = 0; $i<$count_criterions; $i++)
			{
				$cgrade = (int)$aGradeValue[$i];
				$grade += $cgrade;
				$productCommentCriterion = new ProductCommentCriterion((int)$aGradeCriterium[$i]);
				
				//modificar grade en la tabla product_comment_grade
				if ($productCommentCriterion->id)
					$productCommentCriterion->updateGrade($newComment->id, $cgrade);
			}
			
			if (($count_criterions) > 0)
				$newComment->grade = ($grade / ($count_criterions));
				
			//mensaje cuando no se pueden guardar los criterios del comentario
			if (!$newComment->update())
				return $this->l('An error occurred while saving your comment.');
						
			//mensaje cuando el comentario se guarda correctamente
           	return $this->l('The rating was successfully saved');
		}
		else
		{
			//mensaje cuando no se puede guardar el comentario
			return $this->l('An error occurred while trying to save the comment');
		}
    }
   
    //chequear los criterios
	private function _checkCriterion()
	{
		$action_criterion = Tools::getValue('criterion_action');
		$name = Tools::getValue('criterion');
		if (Tools::isSubmit('submitAddCriterion'))
		{
			global $cookie;
			require_once(dirname(__FILE__).'/ProductCommentCriterion.php');
			$languages = Language::getLanguages();
			$id_criterion = (int)Tools::getValue('id_product_comment_criterion');
			$productCommentCriterion = new ProductCommentCriterion((int)$id_criterion);
			foreach ($languages AS $lang)
				$productCommentCriterion->name[(int)$lang['id_lang']] = Tools::getValue('criterion_'.(int)$lang['id_lang']);
				
			// Check default language criterion name
			$defaultLanguage = new Language((int)(Configuration::get('PS_LANG_DEFAULT')));
			if (!Tools::getValue('criterion_'.$defaultLanguage->id))
			{
				$this->_html .= '<div class="error"><img src="../img/admin/error2.png" />'.$this->l('The field <b>Name</b> is required at least in').' '.$defaultLanguage->name.'</div>';
				return;
			}

			$productCommentCriterion->id_product_comment_criterion_type = (int)Tools::getValue('criterion_type');
			$productCommentCriterion->active = (int)Tools::getValue('criterion_active');

			if ($productCommentCriterion->save())
				$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.(Tools::getValue('editCriterion') ? $this->l('Criterion updated') : $this->l('Criterion added')).'</div>';
		}
		elseif (!empty($action_criterion) AND empty($name))
		{
			$id_product_comment_criterion = Tools::getValue('id_product_comment_criterion');
			require_once(dirname(__FILE__).'/ProductCommentCriterion.php');
			switch ($action_criterion)
			{
				case 'edit':
					ProductCommentCriterion::update($id_product_comment_criterion,
						Tools::getValue('criterion_id_lang'),
						Tools::getValue('criterion_name'));
					break;
				case 'delete':
					ProductCommentCriterion::delete($id_product_comment_criterion);
					break;
				default:
					;
			}
		}
	}
	
	//modificar los criterios
	private function _updateApplicationCriterion()
	{
		if (Tools::isSubmit('submitApplicationCriterion'))
		{
			include_once(dirname(__FILE__).'/ProductCommentCriterion.php');
			
			$id_criterion = (int)Tools::getValue('id_criterion');
			$productCommentCriterion = new ProductCommentCriterion((int)$id_criterion);
			if ($productCommentCriterion->id)
			{
				if ($productCommentCriterion->id_product_comment_criterion_type == 2)
				{
					$productCommentCriterion->deleteCategories();
					if ($categories = Tools::getValue('id_product'))
						if (sizeof($categories))
							foreach ($categories AS $id_category)
								$productCommentCriterion->addCategory((int)$id_category);
				}
				elseif ($productCommentCriterion->id_product_comment_criterion_type == 3)
				{
					$productCommentCriterion->deleteProducts();
					if ($products = Tools::getValue('id_product'))
						if (sizeof($products))
							foreach ($products AS $product)
								$productCommentCriterion->addProduct((int)$product);
				}
			}
						
			$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.$this->l('Settings updated').'</div>';
		}
	}

	//formulario de configuración de criterios	
	private function _displayFormConfigurationCriterion()
	{
		global $cookie;
		
		$langs = Language::getLanguages(false);
		$id_lang_default = (int)Configuration::get('PS_LANG_DEFAULT');
		
		$id_criterion = (int)Tools::getValue('editCriterion');
		$criterion = new ProductCommentCriterion((int)$id_criterion);
		$languageIds = 'criterion';
		$this->_html .= '
		<fieldset class="width4">
			<legend><img src="'.$this->_path.'img/note.png" alt="" />'.$this->l('Add a new comment criterion').'</legend>
				<p style="margin-bottom: 20px;">'.$this->l('You can define several criterions to help your customers during their review. For instance: efficiency, lightness, design.').'<br />
				<br />'.$this->l('You can add a new criterion below:').'</p>
				<form action="'.$this->_baseUrl.'" method="post" name="criterion_form">
				<label>'.$this->l('Name').'</label>
				<div class="margin-form">
				<input type="hidden" name="id_product_comment_criterion" value="'.(int)$criterion->id.'" />';
				foreach ($langs AS $lang)
					$this->_html .= '
					<div id="criterion_'.(int)$lang['id_lang'].'" style="display: '.($lang['id_lang'] == $id_lang_default ? 'block' : 'none').'; float: left;">
						<input value="'.$criterion->name[(int)$lang['id_lang']].'" type="text" class="text" name="criterion_'.(int)$lang['id_lang'].'" />
					</div>';
				$this->_html .= $this->displayFlags($langs, (int)$id_lang_default, $languageIds, 'criterion', true);
				$this->_html .= '
				</div>
				<div class="clear">&nbsp;</div>
				<label for="criterion_type">'.$this->l('Apply to').'</label>
				<div class="margin-form">
					<select name="criterion_type">';
				foreach ($this->_productCommentsCriterionTypes AS $k => $type)
					$this->_html.= '<option value="'.(int)$k.'" '.($k == $criterion->id_product_comment_criterion_type ? 'selected="selected"' : '').'>'.$type.'</option>';
				$this->_html .= '</select>
				</div>
				<label>'.$this->l('Active').'</label>
				<div class="margin-form">
					<input type="radio" name="criterion_active" id="active_on" value="1" '.($criterion->active ? 'checked="checked" ' : '').'/>
					<label class="t" for="active_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
					<input type="radio" name="criterion_active" id="active_off" value="0" '.(!$criterion->active ? 'checked="checked" ' : '').'/>
					<label class="t" for="active_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
				</div>
				<div class="margin-form">
					<input type="submit" name="submitAddCriterion" value="'.(Tools::getValue('editCriterion') ? $this->l('Modify this criterion') : $this->l('Add this criterion')).'" class="button" />
				</div>
				</form>';
				require_once(dirname(__FILE__).'/ProductCommentCriterion.php');
				$criterions = ProductCommentCriterion::getCriterions((int)$cookie->id_lang);
				if (sizeof($criterions))
				{
						 $this->_html.= '<br />
						 <table class="table">
						 <thead>
						  <tr>
							<th style="width:260px;">'.$this->l('Criterion').'</th>
							<th style="width:260px;">'.$this->l('Type').'</th>
							<th style="width:50px;">'.$this->l('Status').'</th>
							<th style="width:30px;">'.$this->l('Actions').'</th>
						  </tr>
						 </thead>
						 <tbody>';
				
						foreach ($criterions AS $criterion)
						{
							$this->_html .= '<tr>
							 <td>'.$criterion['name'].'</td>
							 <td>'.$this->_productCommentsCriterionTypes[(int)$criterion['id_product_comment_criterion_type']].'</td>
							 <td style="text-align:center;"><img src="../img/admin/'.($criterion['active'] ? 'enabled' : 'disabled').'.gif" /></td>
							 <td><a href="'.$this->_baseUrl.'&editCriterion='.(int)$criterion['id_product_comment_criterion'].'"><img src="../img/admin/edit.gif" alt="'.$this->l('Edit').'" /></a>
								<a href="'.$this->_baseUrl.'&deleteCriterion='.(int)$criterion['id_product_comment_criterion'].'"><img src="../img/admin/delete.gif" alt="'.$this->l('Delete').'" /></a></td><tr>';
						}
					$this->_html .= '</tbody></table>';
				}
			$this->_html .= '</fieldset><br />';
	}

	//Formulario de criterios
	private function _displayFormApplicationCriterion()
	{
		global $cookie;

		include_once(dirname(__FILE__).'/ProductCommentCriterion.php');

		$criterions = ProductCommentCriterion::getCriterions((int)$cookie->id_lang, false, true);
		$id_criterion = (int)Tools::getValue('updateCriterion');
		
		if ($id_criterion)
		{
			$criterion = new ProductCommentCriterion((int)$id_criterion);
			if ($criterion->id_product_comment_criterion_type == 2)
			{
				$categories = Category::getSimpleCategories((int)$cookie->id_lang);
				$criterion_categories = $criterion->getCategories();
			}
			elseif ($criterion->id_product_comment_criterion_type == 3)
			{
				$criterion_products = $criterion->getProducts();
				$products = Product::getSimpleProducts((int)$cookie->id_lang);
			}
		}

		foreach ($criterions AS $key => $foo)
			if ($foo['id_product_comment_criterion_type'] == 1)
				unset($criterions[$key]);
		
		if (sizeof($criterions))
		{
			$this->_html .= '
			<fieldset class="width2">
				<legend><img src="'.$this->_path.'img/note_go.png" alt="" title="" />'.$this->l('Manage criterions scope').'</legend>
				<p style="margin-bottom: 15px;">'.$this->l('Only criterions restricted to categories or products can be configured below:').'</p>
				<form action="'.$this->_baseUrl.'" method="post" name="product_criterion_form">
					<label>'.$this->l('Criterion').'</label>
					<div class="margin-form">
						<select name="id_product_comment_criterion" id="id_product_comment_criterion" onchange="window.location=\''.$this->_baseUrl.'&updateCriterion=\'+$(\'#id_product_comment_criterion option:selected\').val()">
							<option value="--">-- '.$this->l('Choose a criterion').' --</option>';
						foreach ($criterions AS $foo)
								$this->_html .= '<option value="'.(int)($foo['id_product_comment_criterion']).'" '.($foo['id_product_comment_criterion'] == $id_criterion ? 'selected="selected"' : '').'>'.$foo['name'].'</option>';
			$this->_html .= '</select>
					</div>
				</form>';

			if ($id_criterion AND $criterion->id_product_comment_criterion_type != 1)
			{
				$this->_html .='<label for="id_product_comment_criterion">'.($criterion->id_product_comment_criterion_type == 3 ? $this->l('Products') : $this->l('Categories')).'</label>
					<form action="'.$this->_baseUrl.'" method="post" name="comment_form">
						<div id="product_criterions" class="margin-form">
							<input type="hidden" name="id_criterion" id="id_criterion" value="'.(int)$id_criterion.'" />
							 <br /><table class="table" border="0" cellspacing="0" cellpadding="0">
							 <thead>
							  <tr>
								<th><input class="noborder" type="checkbox" name="id_product[]" onclick="checkDelBoxes(this.form, \'id_product[]\', this.checked);" /></th>
								<th style="width: 30px;">'.$this->l('ID').'</th>
								<th style="width: 550px;">'.($criterion->id_product_comment_criterion_type == 3 ? $this->l('Product Name') : $this->l('Category Name')).'</th>
							  </tr>
							 </thead>
							 <tbody>';
				
				if ($criterion->id_product_comment_criterion_type == 3)	
					foreach ($products AS $product)
						$this->_html .='<tr><td><input class="noborder" type="checkbox" value="'.(int)$product['id_product'].'" name="id_product[]" '.(in_array($product['id_product'], $criterion_products) ? 'checked="checked"' : '').' /></td>
											<td>'.(int)$product['id_product'].'</td><td>'.$product['name'].'</td></tr>';
				elseif ($criterion->id_product_comment_criterion_type == 2)
					foreach ($categories AS $category)
						$this->_html .='<tr><td><input class="noborder" type="checkbox" value="'.(int)$category['id_category'].'" name="id_product[]" '.(in_array($category['id_category'], $criterion_categories) ? 'checked="checked"' : '').' /></td>
											<td>'.(int)$category['id_category'].'</td><td>'.$category['name'].'</td></tr>';
				$this->_html .='</tbody>
						 </table>
						</div>
						<div class="margin-form clear">
							<input type="submit" name="submitApplicationCriterion" value="'.$this->l('Save').'" class="button" />
						</div>
					</form>';
			}
			
			$this->_html .= '</fieldset>';
		}
	}
		
//////////////////////////////////////////////////////////////////////////////////////////
//FRONT OFFICE
//////////////////////////////////////////////////////////////////////////////////////////

	//añadimos a la cabecera de los hooks el proceso de post de front office
	public function hookHeader()
	{
		$this->_frontOfficePostProcess();        
	}

	//Post procesos del front office
	private function _frontOfficePostProcess()
	{
		global $smarty, $cookie, $errors;

		require_once(dirname(__FILE__).'/ProductComment.php');
		require_once(dirname(__FILE__).'/ProductCommentCriterion.php');

	}
	
	//muestra en negro el título de comentarios al final de la página del producto
	public function hookProductTab($params)
    {
		global $smarty, $cookie;
		
		require_once(dirname(__FILE__).'/ProductComment.php');
		require_once(dirname(__FILE__).'/ProductCommentCriterion.php');
		
		$smarty->assign(array(
		'allow_guests' => (int)Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS'),
		'comments' => ProductComment::getByProduct((int)($_GET['id_product'])),
		'criterions' => ProductCommentCriterion::getByProduct((int)($_GET['id_product']), (int)($cookie->id_lang)),
		'nbComments' => (int)(ProductComment::getCommentNumber((int)($_GET['id_product'])))));

		return ($this->display(__FILE__, '/tab.tpl'));
	}
	
	//muestra los comentarios existentes debajo del hook product tab
    public function hookProductTabContent($params)
    {
		global $smarty, $cookie;

		$id_guest = (!$id_customer = (int)$cookie->id_customer) ? (int)$cookie->id_guest : false;
		$customerComment = ProductComment::getByCustomer((int)(Tools::getValue('id_product')), (int)$cookie->id_customer, true, (int)$id_guest);
		
		$averages = ProductComment::getAveragesByProduct((int)Tools::getValue('id_product'), (int)$cookie->id_lang);
		$averageTotal = 0;
		foreach ($averages AS $average)
			$averageTotal += (float)($average);
		$averageTotal = count($averages) ? ($averageTotal / count($averages)) : 0;
		
		/*cambiado
		Judith Buetas
		25/11/2011
		añadimos link para mostrar todos los comentarios			
		*/
		
		$num_comments_display = (int)Configuration::get('PRODUCT_COMMENTS_NUM_DISPLAY');

		$comments = ProductComment::getByProduct((int)Tools::getValue('id_product'),1,$num_comments_display);
		foreach($comments as $comment)
		{
			$aGrades = ProductComment::getGradesByProductComment((int)$comment['id_product_comment']);
			foreach($aGrades as $grade)
			{
				$grades[$comment['id_product_comment']][$grade['id_product_comment_criterion']] = $grade['grade'];
			}
		}
		
		$showAllCommentsButton = false;
		
		if(ProductComment::getCommentNumber((int)Tools::getValue('id_product')) > $num_comments_display)
		{
		 	$showAllCommentsButton = true;
		}
		
		if(isset($_REQUEST['allComments']))
		{
			$num_comments_display = null;
			$showAllCommentsButton = false;
		}

		session_start();
		
		$_SESSION['fbAppId']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID');
		$_SESSION['fbsecret']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET');
		$_SESSION['consumer_key']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY');
		$_SESSION['consumer_secret']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET');
	
		$smarty->assign(array(
		'logged' => (int)$cookie->id_customer,
		'action_url' => '',
		'comments' => $comments,
		'criterions' => ProductCommentCriterion::getByProduct((int)Tools::getValue('id_product'), (int)$cookie->id_lang),
		'averages' => $averages,
		'grades' => $grades,
		'product_comment_path' => $this->_path,
		'averageTotal' => $averageTotal,
		'id_product' => Tools::getValue('id_product'),
		'allow_guests' => (int)Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS'),
		'too_early' => ($customerComment AND (strtotime($customerComment['date_add']) + Configuration::get('PRODUCT_COMMENTS_MINIMAL_TIME')) > time()),
		'showAllCommentsButton' => $showAllCommentsButton,
		'delay' => Configuration::get('PRODUCT_COMMENTS_MINIMAL_TIME'),
		'fbActive' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_ACTIVE'),
		'fbAppId' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID'),
		'fbsecret' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET'),
		'twActive' => Configuration::get('PRODUCT_COMMENTS_TWITTER_ACTIVE'),
		'consumer_key' => Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY'),
		'consumer_secret' => Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET')
		));
			
		return ($this->display(__FILE__, '/productcomments.tpl'));
	}
    
    //ESTANDAR - NO MODIFICADO
    public function hookExtraRight()
	{
		global $smarty, $cookie;

		$id_guest = (!$id_customer = (int)$cookie->id_customer) ? (int)$cookie->id_guest : false;
		$customerComment = ProductComment::getByCustomer((int)(Tools::getValue('id_product')), (int)$cookie->id_customer, true, (int)$id_guest);
		
		$averages = ProductComment::getAveragesByProduct((int)Tools::getValue('id_product'), (int)$cookie->id_lang);
		$averageTotal = 0;
		foreach ($averages AS $average)
			$averageTotal += (float)($average);
		$averageTotal = count($averages) ? ($averageTotal / count($averages)) : 0;
		
		$smarty->assign(array(
		'logged' => (int)$cookie->id_customer,
		'action_url' => '',
		'comments' => ProductComment::getByProduct((int)Tools::getValue('id_product')),
		'criterions' => ProductCommentCriterion::getByProduct((int)Tools::getValue('id_product'), (int)$cookie->id_lang),
		'averages' => $averages,
		'product_comment_path' => $this->_path,
		'averageTotal' => $averageTotal,
		'allow_guests' => (int)Configuration::get('PRODUCT_COMMENTS_ALLOW_GUESTS'),
		'too_early' => ($customerComment AND (strtotime($customerComment['date_add']) + Configuration::get('PRODUCT_COMMENTS_MINIMAL_TIME')) > time()),
		'delay' => Configuration::get('PRODUCT_COMMENTS_MINIMAL_TIME')));

		$controller = new FrontController();
		$controller->pagination((int)ProductComment::getCommentNumber((int)Tools::getValue('id_product')));
		
		return ($this->display(__FILE__, '/productcomments_extraright.tpl'));
	}

	//ESTANDAR - NO MODIFICADO
	public function hookExtraProductComparison($params)
	{
		global $smarty, $cookie;
	
		$list_grades = array();
		$list_product_grades = array();
		$list_product_average = array();
		$list_product_comment = array();
		
		foreach ($params['list_ids_product'] AS $id_product)
		{
			$grades = ProductComment::getAveragesByProduct((int)$id_product, (int)$cookie->id_lang);
			$criterions = ProductCommentCriterion::getByProduct((int)$id_product, (int)$cookie->id_lang);
			$grade_total = 0;
			if (sizeof($grades) > 0)
			{
				foreach ($criterions AS $criterion)
				{					
					$list_product_grades[$criterion['id_product_comment_criterion']][$id_product] = $grades[$criterion['id_product_comment_criterion']];
					$grade_total += (float)($grades[$criterion['id_product_comment_criterion']]);
					
					if (!array_key_exists($criterion['id_product_comment_criterion'], $list_grades))
						$list_grades[$criterion['id_product_comment_criterion']] = $criterion['name'];
				}
				
				$list_product_average[$id_product] = $grade_total / sizeof($criterion);
				$list_product_comment[$id_product] = ProductComment::getByProduct($id_product, 0, 3);
			}
		}				
		
		if (sizeof($list_grades) < 1) 
			return false;
			
		$smarty->assign(array('grades' => $list_grades,	'product_grades' => $list_product_grades, 'list_ids_product' => $params['list_ids_product'], 
		'list_product_average' => $list_product_average, 'product_comments' => $list_product_comment));
		
		return $this->display(__FILE__,'/products-comparison.tpl');
	}
    
    //ESTANDAR - NO MODIFICADO
    public function hookAverageCommentProduct($products){
        global $cookie;
        
        $products_new = array();        
        foreach ($products AS $product){ 
    		$averages = ProductComment::getAveragesByProduct((int)$product['id_product'], (int)$cookie->id_lang);
    		$averageTotal = 0;
    		foreach ($averages AS $average)
    			$averageTotal += (float)($average);
    		$averageTotal = count($averages) ? ($averageTotal / count($averages)) : 0;
        
            $product['comments'] = ProductComment::getByProduct($product['id_product']);
            $product['criterions'] = ProductCommentCriterion::getByProduct((int)$product['id_product'], (int)$cookie->id_lang);
            $product['averages'] = $averages;
            $product['averageTotal'] = $averageTotal;
            
            $products_new[] = $product;
        }
        return $products_new;
    }
    
    //ESTANDAR - NO MODIFICADO
    private function addAverageCommentProductHook() {
        return Db::getInstance()->Execute('INSERT INTO `' . _DB_PREFIX_ . 'hook` (`name`, `title`, `description`, `position`) VALUES (\'averageCommentProduct\', \'AverageCommentProduct\', \'AverageCommentProduct\', 1)');
    }

	//ESTANDAR - NO MODIFICADO
    private function removeAverageCommentProductHook() {
        return Db::getInstance()->Execute('DELETE FROM `' . _DB_PREFIX_ . 'hook` WHERE `name` = \'averageCommentProduct\'');
    }
    
    public function sendProductCommentMail($values)
    {
    	global $cookie;
    	
    	$to = explode(",", Configuration::get('PRODUCT_COMMENTS_MAIL_NOTICE'));
        @Mail::Send((int)($cookie->id_lang), 'notify_product_comment', $this->l('Someone has sent a product comment'), $values, $to, NULL, NULL, NULL, NULL, NULL, dirname(__FILE__).'/mails/');               			
    }
}
