<?php
/*
* 2011 Judith Buetas Solanellas
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future.
*
*  @author Judith Buetas Solanellas <jbuetass@uoc.edu>
*  @copyright  2011 Judith Buetas Solanellas
*  @date 27/11/2011
*  @version  Release: $Revision: 1.0 $
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*/
//////////////////////////////////////////////////////////////////////////////////////////
//INSTALACIÓN
//////////////////////////////////////////////////////////////////////////////////////////

if (!defined('_CAN_LOAD_FILES_'))
	exit;
	
define('LIMIT_SOME_COMMENTS', 3);
define('LIMIT_BY_LINE_OF_COMMENT', 100);

class ShopFeedback extends Module
{
	const INSTALL_SQL_FILE = 'install.sql';
	const UNINSTALL_SQL_FILE = 'uninstall.sql';

	private $_html = '';
	private $_postErrors = array();
	
	private $_productCommentsCriterionTypes = array();
	private $_baseUrl;
	
	const NUM_ITEMS_PAGINATOR = 10;
	
// Judith Buetas Solanellas	
// 27/11/2011
// Constructor de la clase Shop Feedback
	public function __construct()
	{
		$this->name = 'shopfeedback';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this->author = 'Judith Buetas';
		$this->need_instance = 0;
		$this->total_num_stars = (int)Configuration::get('FEEDBACK_TOTAL_NUM_STARS');
		$this->number_comments_per_page  = (int)Configuration::get('FEEDBACK_COMMENTS_NUM_DISPLAY');        
		parent::__construct();
		$this->page = basename(__FILE__, '.php'); //ubicamos la ruta hacia nuestro archivo
		$this->displayName = $this->l('Shop Feedback Comments');
		$this->description = $this->l('Allow users to post comment about the shop').'.';
		
		// Generate warnings:  comprobar que módulo productComments está activado
		$product_comments_var = Configuration::get('PRODUCT_COMMENTS_MODERATE');
		if (!isset($product_comments_var))
		    $this->warning = $this->l('You must have Product Comments activated').'.';
		    
		// Warning uninstall
		$this->confirmUninstall = $this->l('Are you sure you want uninstall this module ? All your configuration will be lost').'.';
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Instalamos el módulo desde el apartado de módulos del Back Office
// Crea tablas de la BD, crea variables de configuration, copia archivos, traslada módulos (registerHook), etc. y comprueba su correcta instalación
	public function install()
	{
		//install tables
        if (!file_exists(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return (false);
		elseif (!$sql = file_get_contents(dirname(__FILE__).'/'.self::INSTALL_SQL_FILE))
			return (false);
            
		$sql = str_replace('PREFIX_', _DB_PREFIX_, $sql);
		$sql = preg_split("/;\s*[\r\n]+/",$sql);

		foreach ($sql as $query)
			if (!Db::getInstance()->Execute(trim($query)))
			     return false;		

		//create config vars
		if (!parent::install()
			OR !$this->registerHook('leftColumn')
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_MODERATE', 1)
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_ALLOW_GUESTS', 0)
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_MINIMAL_TIME', 30)
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_NOTIFY_EMAIL', 1)
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_MAIL_NOTICE','')
            OR !Configuration::updateValue('FEEDBACK_COMMENTS_NUM_DISPLAY', 10)
            OR !Configuration::updateValue('FEEDBACK_TOTAL_NUM_STARS', 5)
            OR !Configuration::updateValue('FEEDBACK_ENABLE_CAPTCHA', 1) 
            OR !Configuration::updateValue('FEEDBACK_NUM_DAY_SEND_EMAIL', 5)
			)
			return false;

		return true;
		
		/* product comments modificar
		if (parent::install() == false 
			OR $this->registerHook('productTab') == false
			OR $this->registerHook('extraProductComparison') == false 
			OR $this->registerHook('productTabContent') == false
			OR $this->registerHook('header') == false 
        	OR !$this->addAverageCommentProductHook()        
        	OR $this->registerHook('averageCommentProduct') == false
        	OR $this->registerHook('extraRight') == false
        )
*/
	
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Desinstalamos el módulo desde el apartado de módulos del Back Office
// Elimina tablas de la Base de datos y variables de configuracion
	function uninstall()
	{
		//uninstall tables
		if (!file_exists(dirname(__FILE__).'/'.self::UNINSTALL_SQL_FILE)) {
			echo $this->l('Cannot find [uninstall.sql]! (aborted)');
			return (false); 
        }else if (!$sql = file_get_contents(dirname(__FILE__).'/'.self::UNINSTALL_SQL_FILE)) {
			echo $this->l('Cannot open [uninstall.sql]! (aborted)');
			return (false); 
        }
        
		$sql = str_replace('PREFIX_', _DB_PREFIX_, $sql);
		$sql = preg_split("/;\s*[\r\n]+/",$sql);
		foreach ($sql as $query)
			if (!Db::getInstance()->Execute(trim($query))) {
                echo $this->l('Cannot remove shop_feedback table from database! (aborted)');
			return false;
		}
		
		//delete config vars
		if (!parent::uninstall() 
			OR !Configuration::deleteByName('FEEDBACK_COMMENTS_MODERATE')
            OR !Configuration::deleteByName('FEEDBACK_COMMENTS_ALLOW_GUESTS')
            OR !Configuration::deleteByName('FEEDBACK_COMMENTS_MINIMAL_TIME')
            OR !Configuration::deleteByName('FEEDBACK_COMMENTS_NOTIFY_EMAIL')
            OR !Configuration::deleteByName('FEEDBACK_COMMENTS_MAIL_NOTICE')
            OR !Configuration::deleteByName('FEEDBACK_COMMENTS_NUM_DISPLAY')
            OR !Configuration::deleteByName('FEEDBACK_TOTAL_NUM_STARS')
            OR !Configuration::deleteByName('FEEDBACK_ENABLE_CAPTCHA') 
            OR !Configuration::deleteByName('FEEDBACK_NUM_DAY_SEND_EMAIL')
			)
			return false;
			
		return true;
		
		
		/*productcomments modificar
		if (!parent::uninstall() 
			OR !$this->removeAverageCommentProductHook() ??? no se que es esto
		)*/
		
	}
		
//////////////////////////////////////////////////////////////////////////////////////////
//BACK OFFICE
//////////////////////////////////////////////////////////////////////////////////////////

// Judith Buetas Solanellas	
// 27/11/2011
// Permite acceder a la configuración del módulo (incluso vacia)
	public function getContent()
	{
		$this->_setBaseUrl();
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_postProcess();
		$this->_checkModerateComment();
		
		return $this->_html.$this->_displayForm();
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Generamos la URL base del módulo Shop Feedback en la administración	
	private function _setBaseUrl()
	{
		$this->_baseUrl = 'index.php?';
		foreach ($_GET AS $k => $value)
				$this->_baseUrl .= $k.'='.$value.'&';
		$this->_baseUrl = rtrim($this->_baseUrl, '&');
	}

// Judith Buetas Solanellas	
// 28/11/2011
// Actualización de los datos de los diferentes apartados de configuración del módulo de Shop Feedback
	protected function _postProcess()
	{		
		if (Tools::isSubmit('submitFeedbackModerate'))
		{
			Configuration::updateValue('FEEDBACK_COMMENTS_MODERATE', (int)Tools::getValue('moderate'));
			Configuration::updateValue('FEEDBACK_COMMENTS_ALLOW_GUESTS', (int)Tools::getValue('allow_guest'));
			Configuration::updateValue('FEEDBACK_COMMENTS_MINIMAL_TIME', (int)Tools::getValue('feedback_comments_minimal_time'));			
			Configuration::updateValue('FEEDBACK_COMMENTS_NOTIFY_EMAIL', Tools::getValue('feedback_comments_notify_email'));
			Configuration::updateValue('FEEDBACK_COMMENTS_MAIL_NOTICE', Tools::getValue('feedback_comments_mail_notice'));
			Configuration::updateValue('FEEDBACK_COMMENTS_NUM_DISPLAY', (int)Tools::getValue('feedback_comments_num_display'));
			Configuration::updateValue('FEEDBACK_TOTAL_NUM_STARS', intval( $_POST['lstTotalNumStars']) );
			Configuration::updateValue('FEEDBACK_ENABLE_CAPTCHA', (int)Tools::getValue('rbEnableCaptcha'));
			Configuration::updateValue('FEEDBACK_NUM_DAY_SEND_EMAIL', $_POST['txtNumDaySendMail'] );
			
			$this->_html .= $this->displayConf($this->l('Settings updated'));
		}
	}
	
// Judith Buetas Solanellas	
// 28/11/2011
// Gestiona los comentarios del feedback
	private function _checkModerateComment()
	{
		require_once(dirname(__FILE__).'/ShopFeedbackSql.php');
		
		$action = Tools::getValue('action');

		if (empty($action) === false && !(int)(Configuration::get('FEEDBACK_COMMENTS_MODERATE')))
		{
			$feedback_comments = Tools::getValue('id_feedback_comment');

			if (sizeof($feedback_comments))
			{		
				switch ($action)
				{
					case 'accept':
						foreach ($feedback_comments AS $id_feedback_comment)
						{
							if (!$id_feedback_comment)
								continue;
							$comment = new ShopFeedbackSql((int)$id_feedback_comment);
							$comment->validate();
						}
						break;
					case 'edit':
						;
					break;
					case 'save':
							if (!$id_feedback_comment)
								continue;
							$comment = new ShopFeedbackSql((int)$id_feedback_comment);
							$comment->update();
						break;
					case 'delete':
						foreach ($feedback_comments AS $id_feedback_comment)
						{
							if (!$id_feedback_comment)
								continue;
							$comment = new ShopFeedbackSql((int)$id_feedback_comment);
							$comment->delete();
						}
						break;
					default:
						;
				}
			}
		}
		
		$action = Tools::getValue('modify_comment_action');
		
		if (empty($action) === false &&
			(int)(Configuration::get('FEEDBACK_COMMENTS_MODERATE')))
		{
			switch ($action)
			{
				case 'update':
						$comment = new ShopFeedbackSql(Tools::getValue('id_comment'));
						$comment->comment = Tools::getValue('comment');
						$comment->comment_grade = Tools::getValue('comment_grade');
						$comment->update();
				break;
					default:
						;
			}
		}
	}
	
// Judith Buetas Solanellas	
// 28/11/2011
// Mostrar mensaje de Datos actualizados
	public function displayConf($text)
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$text.'
		</div>';
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Muestra los diferentes apartados de configuración del módulo de Shop Feedback
	private function _displayForm()
	{
		$this->_html = '';
		$this->_displayFormHeaders();
		$this->_displayInformation();
		$this->_displayFormsFeedback();
		return $this->_html;
	}

	private function _displayFormHeaders()
	{
		$this->_html .= '<script type="text/javascript" src="'.$this->_path.'js/shopfeedback_BO.js"></script>
						<script type="text/javascript" src="'.__PS_BASE_URI__.'js/jquery/jquery-ui-1.8.10.custom.min.js"></script>
						<link rel="stylesheet" href="'.$this->_path.'css/jquery-ui-1.8.10.custom_BO.css" type="text/css" media="all" />
						<link rel="stylesheet" href="'.$this->_path.'css/shopfeedback.css" type="text/css" media="all" />
						<script type="text/javascript" src="'.$this->_path.'js/socialnetworkscomments_BO.js"></script>
						<script type="text/javascript">
							var shopfeedback_dir = "'.$this->_path.'";
							var url_grandeszapatos = "'._PS_BASE_URL_.__PS_BASE_URI__.'";
						</script>';
	}
	
// Judith Buetas Solanellas	
// 27/11/2011
// Muestra información importante sobre el módulo
	private function _displayInformation()
	{
		$this->_html .= '<fieldset>
    			<legend>
                    <span>'.$this->l('Information').'</span>
                </legend>
		 <p>
                    '.$this->l('Product Comments module is required in order this module to  function properly').'.
               	</p>
                <p>
                    '.$this->l('For sending mails "Shop Feedback" is automatic, you must set a cron job using the following URL').': '._PS_BASE_URL_.'/modules/'.$this->name.'/cron.php'.'
               	</p>
                <p style="color:#FE1212;font-weight:bold">                    
                    '.$this->l('Note: If you uninstall the module, all ratings will be deleting. But if you disable the module, the ratings will be continue save').'.
                </p>
            </fieldset>
            <br/>';          
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Muestra formulario de configuración de Feedback de la tienda
	private function _displayFormsFeedback()
	{		
		$this->_html .= $this->_displayFormFeedbackConfiguration();
		
		if (!Configuration::get('PRODUCT_COMMENTS_MODERATE'))
		{
			$this->_html .= $this->_displayFormFeedbackModerate();
		}
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Muestra formulario de configuración de Feedback de la tienda
	private function _displayFormFeedbackConfiguration()
	{
		session_start();
		
		$_SESSION['fbAppId']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID');
		$_SESSION['fbsecret']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET');
		$_SESSION['consumer_key']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY');
		$_SESSION['consumer_secret']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET');
		$_SESSION['consumer_at']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_AT');
		$_SESSION['consumer_ats']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_AT_SECR');
		
		$this->_html .= '<fieldset class="width3">';
		$this->_html .= '<legend><img src="../img/admin/cog.gif" alt="" title="" />'.$this->l('Configuration').'</legend>';
		$this->_html .= '<form action="'.$this->_baseUrl.'" method="post" name="feedback_configuration">';
		
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('All comments must be validated by an employee').'</label>
						<div class="margin-form">
							<input type="radio" name="moderate" id="moderate_on" value="1" '.(Configuration::get('FEEDBACK_COMMENTS_MODERATE') ? 'checked="checked" ' : '').'/>
							<label class="t" for="moderate_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
							<input type="radio" name="moderate" id="moderate_off" value="0" '.(!Configuration::get('FEEDBACK_COMMENTS_MODERATE') ? 'checked="checked" ' : '').'/>
							<label class="t" for="moderate_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
						</div>
						<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('Allow guest comments').'</label>
					<div class="margin-form">
						<input type="radio" name="allow_guest" id="allow_guest_on" value="1" '.(Configuration::get('FEEDBACK_COMMENTS_ALLOW_GUESTS') ? 'checked="checked" ' : '').'/>
						<label class="t" for="allow_guest_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="allow_guest" id="allow_guest_off" value="0" '.(!Configuration::get('FEEDBACK_COMMENTS_ALLOW_GUESTS') ? 'checked="checked" ' : '').'/>
						<label class="t" for="allow_guest_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>
					<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('Minimum time between 2 comments from the same user').'</label>
					<div class="margin-form">
						<input name="feedback_comments_minimal_time" type="text" class="text" value="'.Configuration::get('FEEDBACK_COMMENTS_MINIMAL_TIME').'" style="width: 40px; text-align: right;" /> '.$this->l('seconds').'
					</div>
					<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('notify by email when someone send a new feedback comment').'</label>
					<div class="margin-form">
						<input type="radio" name="feedback_comments_notify_email" id="feedback_comments_notify_email_on" value="1" '.(Configuration::get('FEEDBACK_COMMENTS_NOTIFY_EMAIL') ? 'checked="checked" ' : '').'/>
						<label class="t" for="feedback_comments_notify_email_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
						<input type="radio" name="feedback_comments_notify_email" id="feedback_comments_notify_email_off" value="0" '.(!Configuration::get('FEEDBACK_COMMENTS_NOTIFY_EMAIL') ? 'checked="checked" ' : '').'/>
						<label class="t" for="feedback_comments_notify_email_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					</div>
					<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('mail addresses to notify new feedback comments').'</label>
					<div class="margin-form">
						<input name="feedback_comments_mail_notice" type="text" class="text" size="40" value="'.Configuration::get('FEEDBACK_COMMENTS_MAIL_NOTICE').'"/>
						<p style="font-size:12px">'.$this->l('enter email addresses separated by commas').'</p>
					</div>
					<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('Number of feedback comments to display').'</label>
					<div class="margin-form">
						<input name="feedback_comments_num_display" type="text" class="text" size="5" value="'.Configuration::get('FEEDBACK_COMMENTS_NUM_DISPLAY').'"/>
					</div>
					<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;">'.$this->l('Total number of stars').'</label>
                        <div class="margin-form">
            				<select id="lstTotalNumStars" name="lstTotalNumStars">
            					<option value="1" '.($this->total_num_stars==1 ? 'selected="selected"' : '').'>1</option>
            					<option value="2" '.($this->total_num_stars==2 ? 'selected="selected"' : '').'>2</option>
            					<option value="3" '.($this->total_num_stars==3 ? 'selected="selected"' : '').'>3</option>
            					<option value="4" '.($this->total_num_stars==4 ? 'selected="selected"' : '').'>4</option>
            					<option value="5" '.($this->total_num_stars==5 ? 'selected="selected"' : '').'>5</option>
            					<option value="6" '.($this->total_num_stars==6 ? 'selected="selected"' : '').'>6</option>
            					<option value="7" '.($this->total_num_stars==7 ? 'selected="selected"' : '').'>7</option>
            					<option value="8" '.($this->total_num_stars==8 ? 'selected="selected"' : '').'>8</option>
            					<option value="9" '.($this->total_num_stars==9 ? 'selected="selected"' : '').'>9</option>
            					<option value="10" '.($this->total_num_stars==10 ? 'selected="selected"' : '').'>10</option>
            				</select>                    
                            <p>'.$this->l('Total number of stars you want to use the module.').'</p>
                            <p style="color:red;font-size:12px">'.$this->l('Warning: We you change the number of starts, the current values of the ratings will be change too').'.</p>    
                        </div>
						<div class="clear" style="height: 20px;"></div>';
		$this->_html .= '<label style="padding-top: 0;" for="rbEnableCaptcha">'.$this->l('Enable or disable the anti-machine code (Captcha) when customers leave a comment').': </label>
                        <div class="margin-form">                                                                                 
                            <input type="radio" name="rbEnableCaptcha" value="1" '.(Tools::getValue('rbEnableCaptcha', Configuration::get('FEEDBACK_ENABLE_CAPTCHA')) ? 'checked="checked" ' : '').' />                                                                                
                            <label class="t"> <img title="Enabled" alt="Enabled" src="../img/admin/enabled.gif"></label>                                       
                            <input type="radio" name="rbEnableCaptcha" value="0" '.(!Tools::getValue('rbEnableCaptcha', Configuration::get('FEEDBACK_ENABLE_CAPTCHA')) ? 'checked="checked" ' : '').' />
                            <label class="t"> <img title="Disabled" alt="Disabled" src="../img/admin/disabled.gif"></label>                                          
                        </div>
						<div class="clear" style="height: 20px;"></div>';   
		$this->_html .= '<label>'.$this->l('Number of days to send mail').': </label>
                            <div class="margin-form">
            					<input type="text" size="2" maxlength="2" id="txtNumDaySendMail" name="txtNumDaySendMail" value="'.Configuration::get('FEEDBACK_NUM_DAY_SEND_EMAIL').'" />
                                <p style="font-size:12px">'.$this->l('Set the number of days in which the customer after purchase is made must receive the message asking you to comment and give a punctuation on the shopping experience was in store').'.</p>
            				</div>
            			<div class="clear" style="height: 20px;"></div>';  
		$this->_html .= '<div class="margin-form clear">
						<input type="submit" name="submitFeedbackModerate" value="'.$this->l('Save').'" class="button" />
						</div>';
		$this->_html .= '</form>';
		$this->_html .= '</fieldset><br />';
	}

// Judith Buetas Solanellas	
// 27/11/2011
// Muestra formulario de moderación de Feedback de la tienda
	private function _displayFormFeedbackModerate()
	{
		require_once(dirname(__FILE__).'/ShopFeedbackSql.php');
		
		//Consultamos el listado de los comentarios		
		$normal = false;
		if($normal)
			$comments = ShopFeedbackSql::getByValidate();
		else
		{
			$start_paginator = 0;
			
			if(isset($_REQUEST['submitFilterShopFeedback']))
			{
				$start_paginator = ($_REQUEST['submitFilterShopFeedback']-1)*self::NUM_ITEMS_PAGINATOR;
			}

			$comments = ShopFeedbackSql::getAllComments($start_paginator, self::NUM_ITEMS_PAGINATOR);
		}
				
		$this->_html .= '<fieldset class="width3">';
		$this->_html .= '<legend><img src="'.$this->_path.'img/comments_delete.png" alt="" title="" />'.$this->l('Moderate Comments').'</legend>';

		if (sizeof($comments))
		{		
			//añadimos el dialog que mostraremos al apretar el botón editar del listado
			if(isset($_REQUEST['action']) && ($_REQUEST['action'] == 'edit'))
			{
				$this->_html .= $this->_displayFormEditFeedbackTabContent();
			}
			
			//Mostramos el listado de todos los comentarios junto a un link para eliminarlo o modificarlo			
			if(!$normal)
				$this->_html .= $this->_displayPaginatorFeedbackComments();

			$this->_html .= '<a name="feedback_comments_moderate">&nbsp;</a>
			<form id="comment_form" action="'.$this->_baseUrl.'#feedback_comments_moderate" method="post" name="comment_form">
				<input type="hidden" name="id_feedback_comment[]" id="id_feedback_comment" />
				<input type="hidden" name="action" id="action" />
				<br />
				<table id="table_comments_moderate" class="table" border="0" cellspacing="0" cellpadding="0">
				<thead>
				<tr>
					<th><input class="noborder" type="checkbox" name="id_feedback_comment[]" onclick="checkDelBoxes(this.form, \'id_feedback_comment[]\', this.checked)" /></th>
					<th style="width:150px;">'.ucfirst($this->l('Author')).'</th>
					<th style="width:550px;">'.ucfirst($this->l('Comment')).'</th>
					<th style="width:100px;">'.ucfirst($this->l('Grade')).'</th>
					<th style="width:110px;">'.ucfirst($this->l('Actions')).'</th>
				</tr>
				</thead>
				<tbody>';
				
			foreach ($comments AS $comment)
			{						
				$this->_html .= '
				<tr>
					<td><input class="noborder" type="checkbox" value="'.$comment['id_feedback_comment'].'" name="id_feedback_comment[]" /></td>
				 	<td>'.htmlspecialchars(ucfirst($comment['customer_name']), ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars(ucfirst($comment['comment']), ENT_COMPAT, 'UTF-8').'</td>
				 	<td>'.htmlspecialchars($comment['grade'], ENT_COMPAT, 'UTF-8').'/'.$this->total_num_stars.'</td>
				 	<td>';
//ponemos el id del comentario para enseñarlo, luego lo quitamos
				
				//activar o editar un comentario			
				if($normal) 
					$this->_html .= '<a href="javascript:;" onclick="acceptFeedbackComment('.(int)($comment['id_feedback_comment']).');"><img src="'.$this->_path.'img/accept.png" alt="'.$this->l('Accept').'" title="'.$this->l('Accept').'" /></a>';
				else 
					$this->_html .= '<a href="javascript:;" onclick="editFeedbackComment('.(int)($comment['id_feedback_comment']).');"><img src="'.$this->_path.'img/edit.gif" alt="'.$this->l('Edit').'" title="'.$this->l('Edit').'" /></a>';
							
				$this->_html .= '<a href="javascript:;" onclick="if(confirm(\''.$this->l('are you sure you want to delete this comment?').'\')) deleteFeedbackComment('.(int)($comment['id_feedback_comment']).');"><img src="'.$this->_path.'img/trash.gif" alt="'.$this->l('Delete').'" title="'.$this->l('Delete').'" /></a>';
				
				//añadir un comentario tienda a facebook
				$this->_html .= '<img class="cls_add_comment_to_facebook" src="'.$this->_path.'img/facebook.gif" alt="'.$this->l('Add comment to Facebook').'" title="'.$this->l('Add comment to Facebook').'" />';
						 
				//añadir un comentario tienda a twitter
				$this->_html .= '<img class="cls_add_comment_to_twitter" src="'.$this->_path.'img/twitter.png" alt="'.$this->l('Add comment to Twitter').'" title="'.$this->l('Add comment to Twitter').'" />';
				$this->_html .= '		
				</td>
				</tr>';
			}
			
			$this->_html .= '
				<tr>
					<td colspan="4" style="font-weight:bold;text-align:right">'.$this->l('Selection').':</td>
					<td>';
						if($normal) 
							$this->_html .= '<a href="javascript:;" onclick="acceptFeedbackComment(0);"><img src="'.$this->_path.'img/accept.png" alt="'.$this->l('Accept').'" title="'.$this->l('Accept').'" /></a>';

						$this->_html .= '<a href="javascript:;" onclick="if(confirm(\''.$this->l('are you sure you want to delete this comment?').'\')) deleteFeedbackComment(0);"><img src="'.$this->_path.'img/trash.gif" alt="'.$this->l('Delete').'" title="'.$this->l('Delete').'" /></a>
					</td>
				</tr>
				</tbody>
				</table>
			</form>';
		}
		else
			$this->_html .= $this->l('No comments to validate at this time').'.';

		$this->_html .= '</fieldset><br />';
	}

// Judith Buetas Solanellas	
// 28/11/2011
// Permite paginar los comentarios del feedback desde el BO
	private function _displayPaginatorFeedbackComments()
	{
		global $cookie;
		
		$submitFilterName = "ShopFeedback";
		$action_url = 'index.php?tab=AdminModules&configure='.$this->name;
				
		// Determine total rows number
		$totalRows = ShopFeedbackSql::getFeedbackCommentsNumber();
		
		//Determine number items paginator
		$num_items_paginator = self::NUM_ITEMS_PAGINATOR;

		// Determine total page number
		$totalPages = ceil($totalRows / $num_items_paginator);

		// Determine current page number 
		$page = (int)(Tools::getValue('submitFilter'.$submitFilterName));

		if (!$page) $page = 1;
		
		//Items per page
		$items_ini = $num_items_paginator*$page-$num_items_paginator;
		$items_end = $num_items_paginator*$page;
		
		//Determine last number items paginator
		if($num_items_paginator*$page > (int)$totalRows)
		{
			$items_end = (int)($totalRows);
		}
		
		$text =  '<a name="'.$submitFilterName.'">&nbsp;</a>
		<form method="post" action="'.$action_url.'&token='.Tools::getAdminTokenLite('AdminModules'). '#'.$submitFilterName.'" class="form">
		<input type="hidden" id="submitFilter'.$submitFilterName.'" name="submitFilter'.$submitFilterName.'" value="0">
		<div style="padding: 2px;">';

		if ($page > 1)
			$text .=  '<input type="image" src="../img/admin/list-prev2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value=1"/>&nbsp; 
					<input type="image" src="../img/admin/list-prev.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page - 1).'"/> ';
		$text .=  $this->l('Page').' <b>'.$page.'</b> / '.$totalPages.'&nbsp;';
		
		if ($page < $totalPages)
			$text .=  '<input type="image" src="../img/admin/list-next.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.($page + 1).'"/>&nbsp;
					<input type="image" src="../img/admin/list-next2.gif" onclick="getE(\'submitFilter'.$submitFilterName.'\').value='.$totalPages.'"/>';

		$text .=  ' | '.$this->l('Display').' '.$items_ini.' '.$this->l('to').' '.$items_end.' / '.(int)($totalRows).' '.$this->l('result(s)');
		$text .=  '</div>
		</form>';

		return $text;
	}

// Judith Buetas Solanellas	
// 28/11/2011
// Creamos una función que permita modificar un comentario del feedback desde el BO			
	private function _displayFormEditFeedbackTabContent()
    {
		global $cookie;
		
		$id_feedback_comment = $_REQUEST['id_feedback_comment'][0];
		$comment = ShopFeedbackSql::getByFeedbackCommentId($id_feedback_comment);
		
		$allow_guests = (int)Configuration::get('FEEDBACK_COMMENTS_ALLOW_GUESTS');

		$this->_html .= '<div id="edit_feedback_comment_dialog" title="'.$this->l('Modify this Feedback comment').'">
						<script type="text/javascript" src="'.__PS_BASE_URI__.'js/jquery.rating.pack.js"></script>
						<script type="text/javascript">
							$(function(){ $(\'input[@type=radio].star\').rating(); });
							$(function(){
								$(\'.auto-submit-star\').rating({
									callback: function(value, link){
									}
								});
							});	
							//close  comment form
							function closeCommentForm(){
								$(\'#sendComment\').slideUp(\'fast\');
								$(\'input#addCommentButton\').fadeIn(\'slow\');
							}
						</script>
						
						<script type="text/javascript">
							var allow_guests = '.$allow_guests.';
							var feedback_comments_dir   	= "'._MODULE_DIR_.$this->name.'/";
							var msg_empty_customer_name = "'.$this->l('empty customer name',"shopfeedback").'";
	        				var msg_empty_rate = "'.$this->l('empty rate',"shopfeedback").'";
	        				var msg_empty_comment = "'.$this->l('empty comment',"shopfeedback").'";
						</script>
						
						<form action="'.$this->_baseUrl.'" method="post"  name="modify_comment_form" id="modify_comment_form">
						<input type="hidden" name="modify_comment_action" id="modify_comment_action" />
						<input type="hidden" id="id_feedback_comment_edit" value="'.$comment[0]['id_feedback_comment'].'" />
						
						<input type="hidden" name="id_comment" id="id_comment" />';

		if(($allow_guests == true) && empty($comment[0]['id_customer']))
		{
			$this->_html .= '<label>'.ucfirst($this->l('Name')).'</label>
							<div class="margin-form"><input type="text" name="customer_name" id="customer_name" value="'.$comment[0]['customer_name'].'"/></div>';		
		}

		$this->_html .= '<label>'.ucfirst($this->l('Comment')).'</label>
						<div class="margin-form"><textarea cols="46" rows="5" name="comment" id="comment">'.$comment[0]['comment'].'</textarea></div>';
		$this->_html .= '<label for="comment_grade">'.ucfirst($this->l('Grade')).'</label>
						<div class="margin-form">';
		
		for($i=1;$i<=$this->total_num_stars;$i++)
		{
			$this->_html .= '<input class="star" type="radio" name="comment_grade" value="'.$i.'" '.(($comment[0]['grade'] == $i)  ? " checked=\"checked\" " : "").'/>';
		}
		
		$this->_html .= '</div>';
		$this->_html .= '<div class="margin-form">
						<input type="button" name="btnSaveFeedbackCommentsDialog" id="btnSaveFeedbackCommentsDialog" value="'.$this->l('Save').'" class="button" style="display: inline" />                    
						</div>';		

		$this->_html .= '</form></div><br />';
	}

//////////////////////////////////////////////////////////////////////////////////////////
//FRONT OFFICE - LEFT COLUMN BLOCK OF FEEDBACK COMMENTS
//////////////////////////////////////////////////////////////////////////////////////////

// Judith Buetas Solanellas	
// 05/12/2011
// Guardamos el comentario de feedback
    
    public function _saveFeedbackComment($action, $id_product_comment,$customer_name,$rate,$comment)
    {
        global $cookie;
        
        require_once(dirname(__FILE__).'/ShopFeedbackSql.php');

		if($action == 'save_FO')
		{
			//recoger datos del comentario
			$id_guest = (!$id_customer = (int)$cookie->id_customer) ? (int)$cookie->id_guest : false;	
			$customer_name = ($cookie->id_customer != 0 ? ucwords($cookie->customer_firstname) . " " . ucwords($cookie->customer_lastname) : "Guest");
		
     		$newComment = new ShopFeedbackSql();
	
			$newComment->comment 		= $comment;
			$newComment->id_customer 	= (int)$id_customer;
			$newComment->id_guest 		= (int)$id_guest;
			$newComment->customer_name 	= $customer_name;
			$newComment->grade 			= $rate;
			$newComment->date_add 		= date('Y-m-d H:i:s');
			$newComment->validate 		= !Configuration::get('FEEDBACK_COMMENTS_MODERATE');
		
			//insertar nuevo comentario en la tabla showfeedback
			$resultAdd = $newComment->add();

			if($resultAdd == true)
			{
				//enviamos email de aviso a la administración
				if (Configuration::get('FEEDBACK_COMMENTS_NOTIFY_EMAIL'))
				{  	
					$lastCommentFeedback = $newComment->getLastComment();
					
					if(empty($lastCommentFeedback['customer_name']))
						$customer_name = ($cookie->id_customer != 0 ? ucwords($cookie->customer_firstname) . " " . ucwords($cookie->customer_lastname) : "Guest");
					else
						$customer_name = $lastCommentFeedback['customer_name'];
                    			
					$values = array(
					'{customer_name}' => $customer_name,
					'{grade}' => $lastCommentFeedback['grade']."/". $this->total_num_stars,
					'{comment}' => $lastCommentFeedback['comment']);
			
					$to = explode(",", Configuration::get('FEEDBACK_COMMENTS_MAIL_NOTICE'));
					
					@Mail::Send((int)($cookie->id_lang), 'notify_feedback_comment', $this->l('Someone has sent a feedback comment'), $values, $to, NULL, NULL, NULL, NULL, NULL, dirname(__FILE__).'/mails/');
				}
				
				//mensaje cuando el comentario se guarda correctamente
				if (!Configuration::get('FEEDBACK_COMMENTS_MODERATE'))
					return $this->l('Your rating was successfully saved and will be published after validation!');
				else
					return $this->l('Your rating was successfully saved and published!');
			}
			else
			{
				//mensaje cuando no se puede guardar el comentario
				return $this->l('An error occurred while trying to save the comment');
			}
		}
		else
		{
		 	$originalComment = ShopFeedbackSql::getByFeedbackCommentId($id_product_comment);

			//recoger datos del comentario
			$newComment = new ShopFeedbackSql();
	
			$newComment->id			= (int)$originalComment[0]['id_feedback_comment'];
			$newComment->customer_name 	= $customer_name;
			$newComment->comment_grade	= $rate;
			$newComment->comment 		= $comment;
			$newComment->validate 		= !Configuration::get('FEEDBACK_COMMENTS_MODERATE');

			//modificar comentario en la tabla productcomments
			$resultUpdate = $newComment->update();

			if($resultUpdate == true)
			{			
				//mensaje cuando el comentario se guarda correctamente
           		return $this->l('The rating was successfully saved');
			}
			else
			{
				//mensaje cuando no se puede guardar el comentario
				return $this->l('An error occurred while trying to save the comment');
			}
    	}
    }

// Judith Buetas Solanellas	
// 28/11/2011
//este metodo copia el funcionamiento del anterior
	function hookRightColumn($params)
	{
		return $this->hookLeftColumn($params);
	}
	
// Judith Buetas Solanellas	
// 28/11/2011
// Carga el template que creamos: shopfeedback.tpl en la columna izquierda de la página
	function hookLeftColumn($params)
	{
		global $smarty, $cookie;
		
		require_once(dirname(__FILE__).'/ShopFeedbackSql.php');

		$comment = "";
        $value_comment = 0;

        $aFeed = ShopFeedbackSql::getByValidate(1,'false',' ORDER BY RAND() LIMIT 0,'.LIMIT_SOME_COMMENTS);

        if (sizeof($aFeed))
        {
        	foreach($aFeed as $feed)
        	{
        		$aComments[] = $feed['comment'];
            	$aGrade_comments[] = intval($feed['grade']);
            }
        }  
        
		//asignar valores para smarty
		$smarty->assign(array(
		'remember_email' 	=> Tools::getValue('ifb'),
		'is_logged'       	=> $cookie->logged,
		'base_dir'			=> __PS_BASE_URI__,
		'module_dir'		=>_MODULE_DIR_.$this->name.'/',
		'allow_guests' 		=> Configuration::get('FEEDBACK_COMMENTS_ALLOW_GUESTS'),
		'num_stars'			=> $this->total_num_stars,
		'comments'       	=> (empty ($aComments) ? $this->l('No exists feedbacks') : $aComments),
		'enable_captcha'    => Configuration::get('FEEDBACK_ENABLE_CAPTCHA')
		));
		
		//mostrar plantilla smarty de shopfeedback
		return $this->display(__FILE__, 'shopfeedback.tpl');
	}

//////////////////////////////////////////////////////////////////////////////////////////
//FRONT OFFICE - FEEDBACK COMMENTS LIST
//////////////////////////////////////////////////////////////////////////////////////////
    
// Judith Buetas Solanellas	
// 02/12/2011
// mostrar listado de comentarios de feedback    
	public function viewFeedbackComments($num_page, $star, $filter,$allComments=false)
	{
        global $smarty;          

 		require_once(dirname(__FILE__).'/ShopFeedbackSql.php');
 
 		$ShopFeedbackSql = new ShopFeedbackSql();
 		
        $num_row = 0;
        
        if ($num_page == "")
            $num_page = 1;
        else
            $num_row = ($num_page - 1) * $this->number_comments_per_page;
       
        //number of validated feedback comments
        $result = $ShopFeedbackSql->getNumFeedbackCommentsValidate('1');
        $num_rows_not_filter = $result[0]['count_rows'];
        
       //number of validated feedback comments filtered
        $result = $ShopFeedbackSql->getNumFeedbackCommentsValidate('1',$star,$filter);
        $count_rows = $result[0]['count_rows'];
        $total_pages  = ceil($count_rows / $this->number_comments_per_page);  
        
        //value of total rating
        $result = $ShopFeedbackSql->getTotalRating('1');
        $total_rating_grade = $result[0]['total_rating_grade'];        
        $total_rating_grade = @number_format($total_rating_grade, 1);
        
        //ratings by value star
        $rows_by_star = $ShopFeedbackSql->getRatingByStars('1');
        $arr_rows_by_star = array();

		for ($i=$this->total_num_stars;$i>=1;$i--){
            $arr_rows_by_star[$this->total_num_stars-$i] = array('star' => $i,'total_rows' => 0);

            foreach ($rows_by_star as $row){                     
                if ($row['grade'] == $i){
                    $arr_rows_by_star[$this->total_num_stars-$i] = array('star' => $i,'total_rows' => $row['total_rows']);
                }
            }
		}                 

        /// SELECT RATING validate        
        if($allComments)
            $result = $ShopFeedbackSql->getNumFeedbackCommentsValidate('1',$star,$filter, false);
        else
	        $result = $ShopFeedbackSql->getNumFeedbackCommentsValidate('1',$star,$filter,false,$num_row,$this->number_comments_per_page);

        $smarty->assign(array(
		'total_num_stars'   	=> $this->total_num_stars,
		'star_width'        	=> 22,
		'rows'              	=> $result,
        	'rows_by_star'		=> $arr_rows_by_star,
		'total_pages'       	=> $total_pages,
		'count_rows'         	=> $count_rows,
		'num_rows_not_filter' 	=> $num_rows_not_filter,
		'num_page'          	=> $num_page,
		'allComments'		=> $allComments,
		'total_rating_grade'	=> $total_rating_grade
        ));

	    //mostrar plantilla smarty de shopfeedback
	    return $this->display(__FILE__, 'shopfeedbacklist.tpl');
    }    

//////////////////////////////////////////////////////////////////////////////////////////
//FRONT OFFICE - ALL COMMENTS REMEMBER EMAIL
//////////////////////////////////////////////////////////////////////////////////////////

// Judith Buetas Solanellas	
// 01/12/2011
// Enviamos emails de recuerdo de comentarios de feedback y producto
    public function sendRememberCommentsEmails()
    {
	$shopping_comments_url = 'http://'.Configuration::get('PS_SHOP_DOMAIN')._MODULE_DIR_.$this->name.'/shopfeedbackallcomments.php';
	
        $date = $this->substract_days_to_date(date("d-m-Y"), Configuration::get('FEEDBACK_NUM_DAY_SEND_EMAIL') );

	//pedidos que estan en la tabla orders pero no en la tabla shop_feedback_remember_emails
	$query = "SELECT o.* FROM `"._DB_PREFIX_."orders` AS o
		LEFT OUTER JOIN  `ps_shop_feedback_remember_emails` AS sfre ON o.id_order = sfre.id_order
		WHERE o.`valid` = 1
		AND `date_add` between '".$date." 00:00:00' AND '".$date." 23:59:59'
		AND sfre.id_order IS NULL ";
		//GROUP BY o.`id_customer` "; 

        $rs = Db::getInstance()->ExecuteS($query);

        foreach ($rs AS $row)
        {
            $order = new Order($row['id_order']);
	    
            if (!empty($order))
            {
                $customer = new Customer($row['id_customer']);
                $shopping_comments_url .= "?id=".$row['id_order'];
		
                $data = array(
				'{firstname}' => $customer->firstname,
				'{lastname}' => $customer->lastname,
				'{shopping_comments_url}' => $shopping_comments_url
			);
		
                @Mail::Send((int)($order->id_lang), 'comments_remember_email', $this->l('Give us your feedback'), $data, $customer->email, $customer->firstname.' '.$customer->lastname, NULL, NULL, NULL, NULL, dirname(__FILE__).'/mails/');             
            }                         
        }
        
        return true;        
    }    
    
// Judith Buetas Solanellas	
// 02/12/2011
// Restar x días a una fecha
    function substract_days_to_date($date,$nday)
    {
        if (preg_match("/[0-9]{1,2}\/[0-9]{1,2}\/([0-9][0-9]){1,2}/",$date))
        
        list($day,$month,$year) = explode("/", $date);
        
        if (preg_match("/[0-9]{1,2}-[0-9]{1,2}-([0-9][0-9]){1,2}/",$date))
        
        list($day,$month,$year) = explode("-", $date);
        $newdate = mktime(0,0,0, $month,$day,$year) - $nday * 24 * 60 * 60;
        $newdate = date("Y-m-d",$newdate);
        
        return ($newdate);
    } 
    
// Judith Buetas Solanellas	
// 04/12/2011
// Generar página para añadir comentarios del recordatorio de pedido
	public function feedbackAddAllComments()
	{
		global $smarty, $cookie;
		 
		$id_order = Tools::getValue('id');
		
		if(empty($id_order))
		{
			$smarty->assign(array('error' => $this->l('No order number selected'),
					      'mediumSize' => Image::getSize('medium')));
			return $this->display(__FILE__, 'shopfeedbackallcomments.tpl');
		}
		
		$query = 'SELECT * FROM `'._DB_PREFIX_.'order_detail` WHERE id_order='.$id_order; 
		$result = Db::getInstance()->ExecuteS($query);
	
		if(empty($result))
		{
			$smarty->assign(array('error' => $this->l('There is no request to the selected order number'),
					      'mediumSize' => Image::getSize('medium')));
			return $this->display(__FILE__, 'shopfeedbackallcomments.tpl');
		}
		
		$isCommented = ShopFeedbackSql::checkShopFeedbackOrderCommentsWithMails($id_order);
		
		if(!empty($isCommented))
		{
			$smarty->assign(array('error' => $this->l('The selected order has already been commented'),
					      'mediumSize' => Image::getSize('medium')));
			return $this->display(__FILE__, 'shopfeedbackallcomments.tpl');
		}
		
		session_start();
		
		$_SESSION['fbAppId']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID');
		$_SESSION['fbsecret']		= Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET');
		$_SESSION['consumer_key']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY');
		$_SESSION['consumer_secret']	= Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET');
		
		foreach($result as $aProduct)
		{
			$row = Db::getInstance(_PS_USE_SQL_SLAVE_)->getRow('
			SELECT p.*, pl.`description`, pl.`description_short`, pl.`link_rewrite`, pl.`meta_description`, pl.`meta_keywords`, pl.`meta_title`, pl.`name`, p.`ean13`,  p.`upc`, i.`id_image`, il.`legend`, t.`rate`
			FROM `'._DB_PREFIX_.'product` p
			LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.(int)($cookie->id_lang).')
			LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
			LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.(int)($cookie->id_lang).')
			LEFT JOIN `'._DB_PREFIX_.'tax_rule` tr ON (p.`id_tax_rules_group` = tr.`id_tax_rules_group` AND tr.`id_country` = '.(int)Country::getDefaultCountryId().' AND tr.`id_state` = 0)
			LEFT JOIN `'._DB_PREFIX_.'tax` t ON (t.`id_tax` = tr.`id_tax`)
			WHERE p.id_product = '.(int)$aProduct['product_id']);
			
			$aProducts[]= Product::getProductProperties($id_lang, $row);
		}
		
		$smarty->assign(array(
			'id_order' => $id_order,
			'aProducts' => $aProducts,
			'mediumSize' => Image::getSize('medium'),
			'criterions' => ProductCommentCriterion::getByProduct((int)$aProduct['product_id'], (int)$cookie->id_lang),
			'fbActive' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_ACTIVE'),
			'fbAppId' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_APP_ID'),
			'fbsecret' => Configuration::get('PRODUCT_COMMENTS_FACEBOOK_SECRET'),
			'twActive' => Configuration::get('PRODUCT_COMMENTS_TWITTER_ACTIVE'),
			'consumer_key' => Configuration::get('PRODUCT_COMMENTS_TWITTER_KEY'),
			'consumer_secret' => Configuration::get('PRODUCT_COMMENTS_TWITTER_SECRET')
		));
		
		return $this->display(__FILE__, 'shopfeedbackallcomments.tpl');
	}
	
	public function sendOrderCommentsAdvice($id_order)
	{
		global $cookie;
		
		$values = array(
                        '{customer_name}' => ucwords($cookie->customer_firstname) . " " . ucwords($cookie->customer_lastname),
                        '{id_order}' => str_pad((int)$id_order, 6, "0", STR_PAD_LEFT)
                    );
			
                $to = explode(",", Configuration::get('FEEDBACK_COMMENTS_MAIL_NOTICE'));
		    
                @Mail::Send((int)($cookie->id_lang), 'notify_feedback_order_comments', $this->l('Someone has sent an order comment'), $values, $to, NULL, NULL, NULL, NULL, NULL, dirname(__FILE__).'/mails/');
	}
//cerrar clase 
}